from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class ultimate_sd_upscale(FastClient):
    """
    Generated client for fewjative/ultimate-sd-upscale
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="3765c151-0f0c-440b-8bf4-f04c6190eaef", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], cfg: float = 8.0, steps: int = 20, denoise: float = 0.2, upscaler: str = '4x-UltraSharp', mask_blur: int = 8, mode_type: str = 'Linear', scheduler: str = 'normal', tile_width: int = 512, upscale_by: float = 2.0, tile_height: int = 512, sampler_name: str = 'euler', tile_padding: int = 32, seam_fix_mode: str = 'None', seam_fix_width: int = 64, negative_prompt: str = '', positive_prompt: str = 'Hey! Have a nice day :D', seam_fix_denoise: float = 1.0, seam_fix_padding: int = 16, seam_fix_mask_blur: int = 8, controlnet_strength: float = 1.0, force_uniform_tiles: bool = True, use_controlnet_tile: bool = True, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            cfg: CFG Defaults to 8.0.
            
            steps: Steps Defaults to 20.
            
            denoise: Denoise Defaults to 0.2.
            
            upscaler: Upscaler Defaults to '4x-UltraSharp'.
            
            mask_blur: Mask Blur Defaults to 8.
            
            mode_type: Mode Type Defaults to 'Linear'.
            
            scheduler: Scheduler Defaults to 'normal'.
            
            tile_width: Tile Width Defaults to 512.
            
            upscale_by: Upscale By Defaults to 2.0.
            
            tile_height: Tile Height Defaults to 512.
            
            sampler_name: Sampler Defaults to 'euler'.
            
            tile_padding: Tile Padding Defaults to 32.
            
            seam_fix_mode: Seam Fix Mode Defaults to 'None'.
            
            seam_fix_width: Seam Fix Width Defaults to 64.
            
            negative_prompt: Negative Prompt Defaults to ''.
            
            positive_prompt: Positive Prompt Defaults to 'Hey! Have a nice day :D'.
            
            seam_fix_denoise: Seam Fix Denoise Defaults to 1.0.
            
            seam_fix_padding: Seam Fix Padding Defaults to 16.
            
            seam_fix_mask_blur: Seam Fix Mask Blur Defaults to 8.
            
            controlnet_strength: ControlNet Strength Defaults to 1.0.
            
            force_uniform_tiles: Force Uniform Tiles Defaults to True.
            
            use_controlnet_tile: Use ControlNet Tile Defaults to True.
            
            seed: Sampling seed, leave Empty for Random Optional.
            
        """
        return self.submit_job("/predictions", image=image, cfg=cfg, steps=steps, denoise=denoise, upscaler=upscaler, mask_blur=mask_blur, mode_type=mode_type, scheduler=scheduler, tile_width=tile_width, upscale_by=upscale_by, tile_height=tile_height, sampler_name=sampler_name, tile_padding=tile_padding, seam_fix_mode=seam_fix_mode, seam_fix_width=seam_fix_width, negative_prompt=negative_prompt, positive_prompt=positive_prompt, seam_fix_denoise=seam_fix_denoise, seam_fix_padding=seam_fix_padding, seam_fix_mask_blur=seam_fix_mask_blur, controlnet_strength=controlnet_strength, force_uniform_tiles=force_uniform_tiles, use_controlnet_tile=use_controlnet_tile, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class parler_tts(FastClient):
    """
    Generated client for cjwbw/parler-tts
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="8d81994c-94a8-40bc-81a7-2c94a85f1f24", api_key=api_key)
    
    def predictions(self, prompt: str = 'Hey, how are you doing today?', description: str = 'A female speaker with a slightly low-pitched voice delivers her words quite expressively, in a very confined sounding environment with clear audio quality. She speaks very fast.', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Text for audio generation Defaults to 'Hey, how are you doing today?'.
            
            description: Provide description of the output audio Defaults to 'A female speaker with a slightly low-pitched voice delivers her words quite expressively, in a very confined sounding environment with clear audio quality. She speaks very fast.'.
            
        """
        return self.submit_job("/predictions", prompt=prompt, description=description, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class text2video_zero(FastClient):
    """
    Generated client for cjwbw/text2video-zero
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="334bacb8-a345-43d7-b75c-8736d0f68c95", api_key=api_key)
    
    def predictions(self, fps: int = 4, prompt: str = 'A horse galloping on a street', model_name: str = 'dreamlike-art/dreamlike-photoreal-2.0', timestep_t0: int = 44, timestep_t1: int = 47, video_length: int = 20, negative_prompt: str = '', motion_field_strength_x: int = 12, motion_field_strength_y: int = 12, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            fps: video frames per second Defaults to 4.
            
            prompt: Input Prompt Defaults to 'A horse galloping on a street'.
            
            model_name: choose your model, the model should be avaliable on HF Defaults to 'dreamlike-art/dreamlike-photoreal-2.0'.
            
            timestep_t0: Perform DDPM steps from t0 to t1. The larger the gap between t0 and t1, the more variance between the frames. Ensure t0 < t1 Defaults to 44.
            
            timestep_t1: Perform DDPM steps from t0 to t1. The larger the gap between t0 and t1, the more variance between the frames. Ensure t0 < t1 Defaults to 47.
            
            video_length: Video length in seconds Defaults to 20.
            
            negative_prompt: Negative Prompt Defaults to ''.
            
            motion_field_strength_x: motion_field_strength_x Defaults to 12.
            
            motion_field_strength_y: motion_field_strength_y Defaults to 12.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", fps=fps, prompt=prompt, model_name=model_name, timestep_t0=timestep_t0, timestep_t1=timestep_t1, video_length=video_length, negative_prompt=negative_prompt, motion_field_strength_x=motion_field_strength_x, motion_field_strength_y=motion_field_strength_y, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.jagilley.controlnet_canny import controlnet_canny
from socaity.sdk.replicate.jagilley.controlnet_depth2img import controlnet_depth2img
from socaity.sdk.replicate.jagilley.controlnet_hed import controlnet_hed
from socaity.sdk.replicate.jagilley.controlnet_hough import controlnet_hough
from socaity.sdk.replicate.jagilley.controlnet_normal import controlnet_normal
from socaity.sdk.replicate.jagilley.controlnet_pose import controlnet_pose
from socaity.sdk.replicate.jagilley.controlnet_scribble import controlnet_scribble
from socaity.sdk.replicate.jagilley.controlnet_seg import controlnet_seg


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class nsfw_image_detection(FastClient):
    """
    Generated client for falcons-ai/nsfw-image-detection
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="8e26b425-7598-435b-8e80-38e58d4b1664", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
        """
        return self.submit_job("/predictions", image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class nsfw_video_detection(FastClient):
    """
    Generated client for lucataco/nsfw-video-detection
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9a2797ac-5ee0-4cff-baea-a9d2f65ac18d", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], safety_tolerance: int = 2, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input video
            
            safety_tolerance: Safety tolerance, 1 is most strict and 6 is most permissive Defaults to 2.
            
        """
        return self.submit_job("/predictions", video=video, safety_tolerance=safety_tolerance, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class kandinsky_2_2(FastClient):
    """
    Generated client for ai-forever/kandinsky-2-2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="5f088af7-76d8-4805-866e-c39157267833", api_key=api_key)
    
    def predictions(self, width: int = 512, height: int = 512, prompt: str = 'A moss covered astronaut with a black background', num_outputs: int = 1, output_format: str = 'webp', num_inference_steps: int = 75, num_inference_steps_prior: int = 25, seed: Optional[int] = None, negative_prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image. Lower the setting if hits memory limits. Defaults to 512.
            
            height: Height of output image. Lower the setting if hits memory limits. Defaults to 512.
            
            prompt: Input prompt Defaults to 'A moss covered astronaut with a black background'.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            output_format: Output image format Defaults to 'webp'.
            
            num_inference_steps: Number of denoising steps Defaults to 75.
            
            num_inference_steps_prior: Number of denoising steps for priors Defaults to 25.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            negative_prompt: Specify things to not see in the output Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, num_outputs=num_outputs, output_format=output_format, num_inference_steps=num_inference_steps, num_inference_steps_prior=num_inference_steps_prior, seed=seed, negative_prompt=negative_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class o1_mini(FastClient):
    """
    Generated client for openai/o1-mini
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9db9fcb1-d35e-4f4e-9130-b55681d04fcc", api_key=api_key)
    
    def predictions(self, max_completion_tokens: int = 4096, prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            max_completion_tokens: Maximum number of completion tokens to generate Defaults to 4096.
            
            prompt: The prompt to send to the model. Do not use if using messages. Optional.
            
        """
        return self.submit_job("/predictions", max_completion_tokens=max_completion_tokens, prompt=prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class tile_morph(FastClient):
    """
    Generated client for andreasjansson/tile-morph
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="6234b606-4f64-4f6c-b87d-cd9d6be23f19", api_key=api_key)
    
    def predictions(self, prompt_end: str, prompt_start: str, width: int = 512, height: int = 512, guidance_scale: float = 7.5, frames_per_second: int = 20, intermediate_output: bool = False, num_inference_steps: int = 50, num_animation_frames: int = 10, num_interpolation_steps: int = 20, seed_end: Optional[int] = None, seed_start: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt_end: Prompt to end the animation with. You can include multiple prompts by separating the prompts with | (the 'pipe' character)
            
            prompt_start: Prompt to start the animation with
            
            width: Width of output video Defaults to 512.
            
            height: Height of output video Defaults to 512.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            frames_per_second: Frames per second in output video Defaults to 20.
            
            intermediate_output: Whether to display intermediate outputs during generation Defaults to False.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            num_animation_frames: Number of frames to animate Defaults to 10.
            
            num_interpolation_steps: Number of steps to interpolate between animation frames Defaults to 20.
            
            seed_end: Random seed for last prompt. Leave blank to randomize the seed Optional.
            
            seed_start: Random seed for first prompt. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", prompt_end=prompt_end, prompt_start=prompt_start, width=width, height=height, guidance_scale=guidance_scale, frames_per_second=frames_per_second, intermediate_output=intermediate_output, num_inference_steps=num_inference_steps, num_animation_frames=num_animation_frames, num_interpolation_steps=num_interpolation_steps, seed_end=seed_end, seed_start=seed_start, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.camenduru.lgm import lgm
from socaity.sdk.replicate.camenduru.lgm_ply_to_glb import lgm_ply_to_glb
from socaity.sdk.replicate.camenduru.metavoice import metavoice
from socaity.sdk.replicate.camenduru.tripo_sr import tripo_sr


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class wan_2_1_1_3b_vid2vid(FastClient):
    """
    Generated client for lucataco/wan-2-1-1-3b-vid2vid
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="78b7326b-ca6a-4fcd-a4e6-11963900b560", api_key=api_key)
    
    def predictions(self, prompt: str, tiled: bool = True, cfg_scale: float = 6.0, num_frames: int = 81, aspect_ratio: str = '832x480', negative_prompt: str = 'low quality, blurry, distorted, disfigured, text, watermark', frames_per_second: int = 16, denoising_strength: float = 0.7, num_inference_steps: int = 40, seed: Optional[int] = None, input_video: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Text prompt describing what you want to generate or modify
            
            tiled: Whether to use tiled sampling for better quality on larger videos Defaults to True.
            
            cfg_scale: Classifier free guidance scale (higher values strengthen prompt adherence) Defaults to 6.0.
            
            num_frames: Number of frames to generate in the output video Defaults to 81.
            
            aspect_ratio: Aspect ratio for the output video Defaults to '832x480'.
            
            negative_prompt: Negative prompt to specify what to avoid in the generation Defaults to 'low quality, blurry, distorted, disfigured, text, watermark'.
            
            frames_per_second: Number of frames per second in the output video Defaults to 16.
            
            denoising_strength: Strength of denoising when using video-to-video mode. Higher values change more content. Defaults to 0.7.
            
            num_inference_steps: Number of sampling steps (higher = better quality but slower) Defaults to 40.
            
            seed: Random seed for reproducible results (leave blank for random) Optional.
            
            input_video: Input video for video-to-video generation Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, tiled=tiled, cfg_scale=cfg_scale, num_frames=num_frames, aspect_ratio=aspect_ratio, negative_prompt=negative_prompt, frames_per_second=frames_per_second, denoising_strength=denoising_strength, num_inference_steps=num_inference_steps, seed=seed, input_video=input_video, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class flux_schnell(FastClient):
    """
    Generated client for black-forest-labs/flux-schnell
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="817bca01-a048-4959-84e3-f8be56044f48", api_key=api_key)
    
    def predictions(self, prompt: str, go_fast: bool = True, megapixels: str = '1', num_outputs: int = 1, aspect_ratio: str = '1:1', output_format: str = 'webp', output_quality: int = 80, num_inference_steps: int = 4, disable_safety_checker: bool = False, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt for generated image
            
            go_fast: Run faster predictions with model optimized for speed (currently fp8 quantized); disable to run in original bf16. Note that outputs will not be deterministic when this is enabled, even if you set a seed. Defaults to True.
            
            megapixels: Approximate number of megapixels for generated image Defaults to '1'.
            
            num_outputs: Number of outputs to generate Defaults to 1.
            
            aspect_ratio: Aspect ratio for the generated image Defaults to '1:1'.
            
            output_format: Format of the output images Defaults to 'webp'.
            
            output_quality: Quality when saving the output images, from 0 to 100. 100 is best quality, 0 is lowest quality. Not relevant for .png outputs Defaults to 80.
            
            num_inference_steps: Number of denoising steps. 4 is recommended, and lower number of steps produce lower quality outputs, faster. Defaults to 4.
            
            disable_safety_checker: Disable safety checker for generated images. Defaults to False.
            
            seed: Random seed. Set for reproducible generation Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, go_fast=go_fast, megapixels=megapixels, num_outputs=num_outputs, aspect_ratio=aspect_ratio, output_format=output_format, output_quality=output_quality, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.levelsio.analog_film import analog_film
from socaity.sdk.replicate.levelsio.brain_flakes_ai import brain_flakes_ai
from socaity.sdk.replicate.levelsio.disposable_camera import disposable_camera
from socaity.sdk.replicate.levelsio.lomography import lomography
from socaity.sdk.replicate.levelsio.neon_tokyo import neon_tokyo


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class jina_clip_v2(FastClient):
    """
    Generated client for zsxkib/jina-clip-v2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2978d47d-bd47-41d1-8d9e-e77e35fc0153", api_key=api_key)
    
    def predictions(self, embedding_dim: int = 64, output_format: str = 'base64', text: Optional[str] = None, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            embedding_dim: Matryoshka dimension - output embedding dimension (64-1024) Defaults to 64.
            
            output_format: Format to use in outputs Defaults to 'base64'.
            
            text: Text content to embed (up to 8192 tokens). If both text and image provided, text embedding will be first in returned list. Optional.
            
            image: Image file to embed (optimal size: 512x512). If both text and image provided, image embedding will be second in returned list. Optional.
            
        """
        return self.submit_job("/predictions", embedding_dim=embedding_dim, output_format=output_format, text=text, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class whisper_diarization(FastClient):
    """
    Generated client for nicknaskida/whisper-diarization
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f6afd38a-eb3a-40d8-988e-21754d3a0c9a", api_key=api_key)
    
    def predictions(self, translate: bool = False, batch_size: int = 64, num_speakers: int = 2, group_segments: bool = True, offset_seconds: int = 0, transcript_output_format: str = 'both', file: Optional[Union[MediaFile, str, bytes]] = None, prompt: Optional[str] = None, file_url: Optional[str] = None, hf_token: Optional[str] = None, language: Optional[str] = None, file_string: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            translate: Translate the speech into English. Defaults to False.
            
            batch_size: Batch size for inference. (Reduce if face OOM error) Defaults to 64.
            
            num_speakers: Number of speakers, leave empty to autodetect. Defaults to 2.
            
            group_segments: Group segments of same speaker shorter apart than 2 seconds Defaults to True.
            
            offset_seconds: Offset in seconds, used for chunked inputs Defaults to 0.
            
            transcript_output_format: Specify the format of the transcript output: individual words with timestamps, full text of segments, or a combination of both. Defaults to 'both'.
            
            file: Or an audio file Optional.
            
            prompt: Vocabulary: provide names, acronyms and loanwords in a list. Use punctuation for best accuracy. Optional.
            
            file_url: Or provide: A direct audio file URL Optional.
            
            hf_token: Provide a hf.co/settings/token for Pyannote.audio to diarise the audio clips. You need to agree to the terms in 'https://huggingface.co/pyannote/speaker-diarization-3.1' and 'https://huggingface.co/pyannote/segmentation-3.0' first. Optional.
            
            language: Language of the spoken words as a language code like 'en'. Leave empty to auto detect language. Optional.
            
            file_string: Either provide: Base64 encoded audio file, Optional.
            
        """
        return self.submit_job("/predictions", translate=translate, batch_size=batch_size, num_speakers=num_speakers, group_segments=group_segments, offset_seconds=offset_seconds, transcript_output_format=transcript_output_format, file=file, prompt=prompt, file_url=file_url, hf_token=hf_token, language=language, file_string=file_string, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class material_maker(FastClient):
    """
    Generated client for midllle/material-maker
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2b381d5e-1ef0-4efb-9876-a68d692f2e0f", api_key=api_key)
    
    def predictions(self, input_image: Union[MediaFile, str, bytes], mirror: bool = False, seamless: bool = False, ishiiruka: bool = False, replicate: bool = False, tile_size: int = 512, ishiiruka_texture_encoder: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_image: Input image
            
            mirror: Mirrored seamless upscaling Defaults to False.
            
            seamless: Seamless upscaling Defaults to False.
            
            ishiiruka: Save textures in Ishiiruka Dolphin material map texture pack format Defaults to False.
            
            replicate: Replicate edge pixels for padding Defaults to False.
            
            tile_size: Tile size for splitting Defaults to 512.
            
            ishiiruka_texture_encoder: Save textures in Ishiiruka Dolphin's Texture Encoder format Defaults to False.
            
        """
        return self.submit_job("/predictions", input_image=input_image, mirror=mirror, seamless=seamless, ishiiruka=ishiiruka, replicate=replicate, tile_size=tile_size, ishiiruka_texture_encoder=ishiiruka_texture_encoder, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class bark(FastClient):
    """
    Generated client for suno-ai/bark
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="7aeef358-94ec-4cc1-abd7-b238ac3a490a", api_key=api_key)
    
    def predictions(self, prompt: str = 'Hello, my name is Suno. And, uh — and I like pizza. [laughs] But I also have other interests such as playing tic tac toe.', text_temp: float = 0.7, output_full: bool = False, waveform_temp: float = 0.7, history_prompt: Optional[str] = None, custom_history_prompt: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Input prompt Defaults to 'Hello, my name is Suno. And, uh — and I like pizza. [laughs] But I also have other interests such as playing tic tac toe.'.
            
            text_temp: generation temperature (1.0 more diverse, 0.0 more conservative) Defaults to 0.7.
            
            output_full: return full generation as a .npz file to be used as a history prompt Defaults to False.
            
            waveform_temp: generation temperature (1.0 more diverse, 0.0 more conservative) Defaults to 0.7.
            
            history_prompt: history choice for audio cloning, choose from the list Optional.
            
            custom_history_prompt: Provide your own .npz file with history choice for audio cloning, this will override the previous history_prompt setting Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, text_temp=text_temp, output_full=output_full, waveform_temp=waveform_temp, history_prompt=history_prompt, custom_history_prompt=custom_history_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class sdxl_controlnet_lora(FastClient):
    """
    Generated client for fermatresearch/sdxl-controlnet-lora
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="1b81bbd8-39b8-4955-add4-8e5265beb41b", api_key=api_key)
    
    def predictions(self, prompt: str = 'An astronaut riding a rainbow unicorn', refine: str = 'base_image_refiner', strength: float = 0.8, scheduler: str = 'K_EULER', lora_scale: float = 0.95, num_outputs: int = 1, refine_steps: int = 10, guidance_scale: float = 7.5, apply_watermark: bool = True, condition_scale: float = 1.1, negative_prompt: str = '', num_inference_steps: int = 30, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, img2img: Optional[bool] = None, lora_weights: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Input prompt Defaults to 'An astronaut riding a rainbow unicorn'.
            
            refine: Whether to use refinement steps or not Defaults to 'base_image_refiner'.
            
            strength: When img2img is active, the denoising strength. 1 means total destruction of the input image. Defaults to 0.8.
            
            scheduler: scheduler Defaults to 'K_EULER'.
            
            lora_scale: LoRA additive scale. Only applicable on trained models. Defaults to 0.95.
            
            num_outputs: Number of images to output Defaults to 1.
            
            refine_steps: For base_image_refiner, the number of steps to refine Defaults to 10.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            apply_watermark: Applies a watermark to enable determining if an image is generated in downstream applications. If you have other provisions for generating or deploying images safely, you can use this to disable watermarking. Defaults to True.
            
            condition_scale: The bigger this number is, the more ControlNet interferes Defaults to 1.1.
            
            negative_prompt: Input Negative Prompt Defaults to ''.
            
            num_inference_steps: Number of denoising steps Defaults to 30.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for img2img or inpaint mode Optional.
            
            img2img: Use img2img pipeline, it will use the image input both as the control image and the base image. Optional.
            
            lora_weights: Replicate LoRA weights to use. Leave blank to use the default weights. Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, refine=refine, strength=strength, scheduler=scheduler, lora_scale=lora_scale, num_outputs=num_outputs, refine_steps=refine_steps, guidance_scale=guidance_scale, apply_watermark=apply_watermark, condition_scale=condition_scale, negative_prompt=negative_prompt, num_inference_steps=num_inference_steps, seed=seed, image=image, img2img=img2img, lora_weights=lora_weights, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class pasd_magnify(FastClient):
    """
    Generated client for lucataco/pasd-magnify
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ebd8b0d6-d26d-45b8-8ec9-4d33df9f714d", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], prompt: str = 'Frog, clean, high-resolution, 8k, best quality, masterpiece', n_prompt: str = 'dotted, noise, blur, lowres, oversmooth, longbody, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality', denoise_steps: int = 20, guidance_scale: float = 7.5, upsample_scale: int = 2, conditioning_scale: float = 1.1, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            prompt: Prompt Defaults to 'Frog, clean, high-resolution, 8k, best quality, masterpiece'.
            
            n_prompt: Negative Prompt Defaults to 'dotted, noise, blur, lowres, oversmooth, longbody, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality'.
            
            denoise_steps: Denoise Steps Defaults to 20.
            
            guidance_scale: Guidance Scale Defaults to 7.5.
            
            upsample_scale: Upsample Scale Defaults to 2.
            
            conditioning_scale: Conditioning Scale Defaults to 1.1.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", image=image, prompt=prompt, n_prompt=n_prompt, denoise_steps=denoise_steps, guidance_scale=guidance_scale, upsample_scale=upsample_scale, conditioning_scale=conditioning_scale, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class mochi_1(FastClient):
    """
    Generated client for genmoai/mochi-1
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9da90610-f223-424d-abbb-2ad6c1d4b1ca", api_key=api_key)
    
    def predictions(self, fps: int = 30, prompt: str = "Close-up of a chameleon's eye, with its scaly skin changing color. Ultra high resolution 4k.", num_frames: int = 163, guidance_scale: float = 6.0, num_inference_steps: int = 64, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            fps: Frames per second Defaults to 30.
            
            prompt: Focus on a single, central subject. Structure the prompt from coarse to fine details. Start with 'a close shot' or 'a medium shot' if applicable. Append 'high resolution 4k' to reduce warping Defaults to "Close-up of a chameleon's eye, with its scaly skin changing color. Ultra high resolution 4k.".
            
            num_frames: Number of frames to generate Defaults to 163.
            
            guidance_scale: The guidance scale for the model Defaults to 6.0.
            
            num_inference_steps: Number of inference steps Defaults to 64.
            
            seed: Random seed Optional.
            
        """
        return self.submit_job("/predictions", fps=fps, prompt=prompt, num_frames=num_frames, guidance_scale=guidance_scale, num_inference_steps=num_inference_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class wonder3d(FastClient):
    """
    Generated client for adirik/wonder3d
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9120889d-ff19-44ed-bfa9-03414b7f71e2", api_key=api_key)
    
    def predictions(self, num_steps: int = 3000, remove_bg: bool = True, image: Optional[Union[MediaFile, str, bytes]] = None, random_seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            num_steps: Number of iterations Defaults to 3000.
            
            remove_bg: Whether to remove image background. Set to false only if uploading image with removed background. Defaults to True.
            
            image: Input image to convert to 3D Optional.
            
            random_seed: Random seed for reproducibility, leave blank to randomize output Optional.
            
        """
        return self.submit_job("/predictions", num_steps=num_steps, remove_bg=remove_bg, image=image, random_seed=random_seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class animatediff_illusions(FastClient):
    """
    Generated client for zsxkib/animatediff-illusions
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="7004e090-b95e-4df1-b93f-0bf02eb1769a", api_key=api_key)
    
    def predictions(self, loop: bool = True, steps: int = 25, width: int = 256, frames: int = 128, height: int = 384, context: int = 16, clip_skip: int = 2, scheduler: str = 'k_dpmpp_sde', base_model: str = 'majicmixRealistic_v5Preview', prompt_map: str = '', head_prompt: str = 'masterpiece, best quality, a haunting and detailed depiction of a ship at sea, battered by waves, ominous,((dark clouds:1.3)),distant lightning, rough seas, rain, silhouette of the ship against the stormy sky', tail_prompt: str = '', output_format: str = 'mp4', guidance_scale: float = 7.5, negative_prompt: str = '', film_interpolation: bool = True, prompt_fixed_ratio: float = 0.5, custom_base_model_url: str = '', num_interpolation_steps: int = 3, enable_qr_code_monster_v2: bool = True, playback_frames_per_second: int = 8, controlnet_conditioning_scale: float = 0.18, qr_code_monster_v2_guess_mode: bool = False, qr_code_monster_v2_preprocessor: bool = True, seed: Optional[int] = None, controlnet_video: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            loop: Flag to loop the video. Use when you have an 'infinitely' repeating video/gif ControlNet video Defaults to True.
            
            steps: Number of inference steps Defaults to 25.
            
            width: Width of generated video in pixels, must be divisable by 8 Defaults to 256.
            
            frames: Length of the video in frames (playback is at 8 fps e.g. 16 frames @ 8 fps is 2 seconds) Defaults to 128.
            
            height: Height of generated video in pixels, must be divisable by 8 Defaults to 384.
            
            context: Number of frames to condition on (default: max of <length> or 32). max for motion module v1 is 24 Defaults to 16.
            
            clip_skip: Skip the last N-1 layers of the CLIP text encoder (lower values follow prompt more closely) Defaults to 2.
            
            scheduler: Diffusion scheduler Defaults to 'k_dpmpp_sde'.
            
            base_model: Choose the base model for animation generation. If 'CUSTOM' is selected, provide a custom model URL in the next parameter Defaults to 'majicmixRealistic_v5Preview'.
            
            prompt_map: Prompt for changes in animation. Provide 'frame number : prompt at this frame', separate different prompts with '|'. Make sure the frame number does not exceed the length of video (frames) Defaults to ''.
            
            head_prompt: Primary animation prompt. If a prompt map is provided, this will be prefixed at the start of every individual prompt in the map Defaults to 'masterpiece, best quality, a haunting and detailed depiction of a ship at sea, battered by waves, ominous,((dark clouds:1.3)),distant lightning, rough seas, rain, silhouette of the ship against the stormy sky'.
            
            tail_prompt: Additional prompt that will be appended at the end of the main prompt or individual prompts in the map Defaults to ''.
            
            output_format: Output format of the video. Can be 'mp4' or 'gif' Defaults to 'mp4'.
            
            guidance_scale: Guidance Scale. How closely do we want to adhere to the prompt and its contents Defaults to 7.5.
            
            negative_prompt: negative_prompt Defaults to ''.
            
            film_interpolation: Whether to use FILM for between-frame interpolation (film-net.github.io) Defaults to True.
            
            prompt_fixed_ratio: Defines the ratio of adherence to the fixed part of the prompt versus the dynamic part (from prompt map). Value should be between 0 (only dynamic) to 1 (only fixed). Defaults to 0.5.
            
            custom_base_model_url: Only used when base model is set to 'CUSTOM'. URL of the custom model to download if 'CUSTOM' is selected in the base model. Only downloads from 'https://civitai.com/api/download/models/' are allowed Defaults to ''.
            
            num_interpolation_steps: Number of steps to interpolate between animation frames Defaults to 3.
            
            enable_qr_code_monster_v2: Flag to enable QR Code Monster V2 ControlNet Defaults to True.
            
            playback_frames_per_second: playback_frames_per_second Defaults to 8.
            
            controlnet_conditioning_scale: Strength of ControlNet. The outputs of the ControlNet are multiplied by `controlnet_conditioning_scale` before they are added to the residual in the original UNet Defaults to 0.18.
            
            qr_code_monster_v2_guess_mode: Flag to enable guess mode (un-guided) for QR Code Monster V2 ControlNet Defaults to False.
            
            qr_code_monster_v2_preprocessor: Flag to pre-process keyframes for QR Code Monster V2 ControlNet Defaults to True.
            
            seed: Seed for different images and reproducibility. Leave blank to randomise seed Optional.
            
            controlnet_video: A short video/gif that will be used as the keyframes for QR Code Monster to use, Please note, all of the frames will be used as keyframes Optional.
            
        """
        return self.submit_job("/predictions", loop=loop, steps=steps, width=width, frames=frames, height=height, context=context, clip_skip=clip_skip, scheduler=scheduler, base_model=base_model, prompt_map=prompt_map, head_prompt=head_prompt, tail_prompt=tail_prompt, output_format=output_format, guidance_scale=guidance_scale, negative_prompt=negative_prompt, film_interpolation=film_interpolation, prompt_fixed_ratio=prompt_fixed_ratio, custom_base_model_url=custom_base_model_url, num_interpolation_steps=num_interpolation_steps, enable_qr_code_monster_v2=enable_qr_code_monster_v2, playback_frames_per_second=playback_frames_per_second, controlnet_conditioning_scale=controlnet_conditioning_scale, qr_code_monster_v2_guess_mode=qr_code_monster_v2_guess_mode, qr_code_monster_v2_preprocessor=qr_code_monster_v2_preprocessor, seed=seed, controlnet_video=controlnet_video, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class interior_design(FastClient):
    """
    Generated client for adirik/interior-design
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="fdc56358-7633-41fa-9880-aa45eb7cf3b2", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], prompt: str, guidance_scale: float = 15.0, negative_prompt: str = 'lowres, watermark, banner, logo, watermark, contactinfo, text, deformed, blurry, blur, out of focus, out of frame, surreal, extra, ugly, upholstered walls, fabric walls, plush walls, mirror, mirrored, functional, realistic', prompt_strength: float = 0.8, num_inference_steps: int = 50, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            prompt: Text prompt for design
            
            guidance_scale: Scale for classifier-free guidance Defaults to 15.0.
            
            negative_prompt: Negative text prompt to guide the design Defaults to 'lowres, watermark, banner, logo, watermark, contactinfo, text, deformed, blurry, blur, out of focus, out of frame, surreal, extra, ugly, upholstered walls, fabric walls, plush walls, mirror, mirrored, functional, realistic'.
            
            prompt_strength: Prompt strength for inpainting. 1.0 corresponds to full destruction of information in image Defaults to 0.8.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", image=image, prompt=prompt, guidance_scale=guidance_scale, negative_prompt=negative_prompt, prompt_strength=prompt_strength, num_inference_steps=num_inference_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class tripo_sr(FastClient):
    """
    Generated client for camenduru/tripo-sr
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="b776d683-2130-46a2-bd09-ef909b81bc0b", api_key=api_key)
    
    def predictions(self, image_path: Union[MediaFile, str, bytes], foreground_ratio: float = 0.85, do_remove_background: bool = True, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image_path: Input Image
            
            foreground_ratio: foreground_ratio Defaults to 0.85.
            
            do_remove_background: do_remove_background Defaults to True.
            
        """
        return self.submit_job("/predictions", image_path=image_path, foreground_ratio=foreground_ratio, do_remove_background=do_remove_background, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class pixart_xl_2(FastClient):
    """
    Generated client for lucataco/pixart-xl-2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ef14d7eb-1ced-43da-b0d0-df66e559a1b5", api_key=api_key)
    
    def predictions(self, style: str = 'None', width: int = 1024, height: int = 1024, prompt: str = 'A small cactus with a happy face in the Sahara desert', scheduler: str = 'DPMSolverMultistep', num_outputs: int = 1, guidance_scale: float = 4.5, num_inference_steps: int = 14, seed: Optional[int] = None, negative_prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            style: Image style Defaults to 'None'.
            
            width: Width of output image Defaults to 1024.
            
            height: Height of output image Defaults to 1024.
            
            prompt: Input prompt Defaults to 'A small cactus with a happy face in the Sahara desert'.
            
            scheduler: scheduler Defaults to 'DPMSolverMultistep'.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 4.5.
            
            num_inference_steps: Number of denoising steps Defaults to 14.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            negative_prompt: Negative prompt Optional.
            
        """
        return self.submit_job("/predictions", style=style, width=width, height=height, prompt=prompt, scheduler=scheduler, num_outputs=num_outputs, guidance_scale=guidance_scale, num_inference_steps=num_inference_steps, seed=seed, negative_prompt=negative_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class train_rvc_model(FastClient):
    """
    Generated client for replicate/train-rvc-model
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9f4a5c71-0e90-4672-838e-ff3d86dcc273", api_key=api_key)
    
    def predictions(self, dataset_zip: Union[MediaFile, str, bytes], epoch: int = 10, version: str = 'v2', f0method: str = 'rmvpe_gpu', batch_size: str = '7', sample_rate: str = '48k', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            dataset_zip: Upload dataset zip, zip should contain `dataset/<rvc_name>/split_<i>.wav`
            
            epoch: Epoch Defaults to 10.
            
            version: Version Defaults to 'v2'.
            
            f0method: F0 method, `rmvpe_gpu` recommended. Defaults to 'rmvpe_gpu'.
            
            batch_size: Batch size Defaults to '7'.
            
            sample_rate: Sample rate Defaults to '48k'.
            
        """
        return self.submit_job("/predictions", dataset_zip=dataset_zip, epoch=epoch, version=version, f0method=f0method, batch_size=batch_size, sample_rate=sample_rate, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class whisperx(FastClient):
    """
    Generated client for victor-upmeet/whisperx
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="200c0572-31f8-4508-9d92-047f97fe36e1", api_key=api_key)
    
    def predictions(self, audio_file: Union[MediaFile, str, bytes], debug: bool = False, vad_onset: float = 0.5, batch_size: int = 64, vad_offset: float = 0.363, diarization: bool = False, temperature: float = 0.0, align_output: bool = False, language_detection_min_prob: float = 0.0, language_detection_max_tries: int = 5, language: Optional[str] = None, max_speakers: Optional[int] = None, min_speakers: Optional[int] = None, initial_prompt: Optional[str] = None, huggingface_access_token: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio_file: Audio file
            
            debug: Print out compute/inference times and memory usage information Defaults to False.
            
            vad_onset: VAD onset Defaults to 0.5.
            
            batch_size: Parallelization of input audio transcription Defaults to 64.
            
            vad_offset: VAD offset Defaults to 0.363.
            
            diarization: Assign speaker ID labels Defaults to False.
            
            temperature: Temperature to use for sampling Defaults to 0.0.
            
            align_output: Aligns whisper output to get accurate word-level timestamps Defaults to False.
            
            language_detection_min_prob: If language is not specified, then the language will be detected recursively on different parts of the file until it reaches the given probability Defaults to 0.0.
            
            language_detection_max_tries: If language is not specified, then the language will be detected following the logic of language_detection_min_prob parameter, but will stop after the given max retries. If max retries is reached, the most probable language is kept. Defaults to 5.
            
            language: ISO code of the language spoken in the audio, specify None to perform language detection Optional.
            
            max_speakers: Maximum number of speakers if diarization is activated (leave blank if unknown) Optional.
            
            min_speakers: Minimum number of speakers if diarization is activated (leave blank if unknown) Optional.
            
            initial_prompt: Optional text to provide as a prompt for the first window Optional.
            
            huggingface_access_token: To enable diarization, please enter your HuggingFace token (read). You need to accept the user agreement for the models specified in the README. Optional.
            
        """
        return self.submit_job("/predictions", audio_file=audio_file, debug=debug, vad_onset=vad_onset, batch_size=batch_size, vad_offset=vad_offset, diarization=diarization, temperature=temperature, align_output=align_output, language_detection_min_prob=language_detection_min_prob, language_detection_max_tries=language_detection_max_tries, language=language, max_speakers=max_speakers, min_speakers=min_speakers, initial_prompt=initial_prompt, huggingface_access_token=huggingface_access_token, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class julienetoke(FastClient):
    """
    Generated client for julienhypeer/julienetoke
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f317a53f-c53a-4fb3-bb23-cabe25f54ac7", api_key=api_key)
    
    def predictions(self, prompt: str, model: str = 'dev', go_fast: bool = False, lora_scale: float = 1.0, megapixels: str = '1', num_outputs: int = 1, aspect_ratio: str = '1:1', output_format: str = 'webp', guidance_scale: float = 3.0, output_quality: int = 80, prompt_strength: float = 0.8, extra_lora_scale: float = 1.0, num_inference_steps: int = 28, disable_safety_checker: bool = False, mask: Optional[Union[MediaFile, str, bytes]] = None, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, width: Optional[int] = None, height: Optional[int] = None, extra_lora: Optional[str] = None, replicate_weights: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt for generated image. If you include the `trigger_word` used in the training process you are more likely to activate the trained object, style, or concept in the resulting image.
            
            model: Which model to run inference with. The dev model performs best with around 28 inference steps but the schnell model only needs 4 steps. Defaults to 'dev'.
            
            go_fast: Run faster predictions with model optimized for speed (currently fp8 quantized); disable to run in original bf16 Defaults to False.
            
            lora_scale: Determines how strongly the main LoRA should be applied. Sane results between 0 and 1 for base inference. For go_fast we apply a 1.5x multiplier to this value; we've generally seen good performance when scaling the base value by that amount. You may still need to experiment to find the best value for your particular lora. Defaults to 1.0.
            
            megapixels: Approximate number of megapixels for generated image Defaults to '1'.
            
            num_outputs: Number of outputs to generate Defaults to 1.
            
            aspect_ratio: Aspect ratio for the generated image. If custom is selected, uses height and width below & will run in bf16 mode Defaults to '1:1'.
            
            output_format: Format of the output images Defaults to 'webp'.
            
            guidance_scale: Guidance scale for the diffusion process. Lower values can give more realistic images. Good values to try are 2, 2.5, 3 and 3.5 Defaults to 3.0.
            
            output_quality: Quality when saving the output images, from 0 to 100. 100 is best quality, 0 is lowest quality. Not relevant for .png outputs Defaults to 80.
            
            prompt_strength: Prompt strength when using img2img. 1.0 corresponds to full destruction of information in image Defaults to 0.8.
            
            extra_lora_scale: Determines how strongly the extra LoRA should be applied. Sane results between 0 and 1 for base inference. For go_fast we apply a 1.5x multiplier to this value; we've generally seen good performance when scaling the base value by that amount. You may still need to experiment to find the best value for your particular lora. Defaults to 1.0.
            
            num_inference_steps: Number of denoising steps. More steps can give more detailed images, but take longer. Defaults to 28.
            
            disable_safety_checker: Disable safety checker for generated images. Defaults to False.
            
            mask: Image mask for image inpainting mode. If provided, aspect_ratio, width, and height inputs are ignored. Optional.
            
            seed: Random seed. Set for reproducible generation Optional.
            
            image: Input image for image to image or inpainting mode. If provided, aspect_ratio, width, and height inputs are ignored. Optional.
            
            width: Width of generated image. Only works if `aspect_ratio` is set to custom. Will be rounded to nearest multiple of 16. Incompatible with fast generation Optional.
            
            height: Height of generated image. Only works if `aspect_ratio` is set to custom. Will be rounded to nearest multiple of 16. Incompatible with fast generation Optional.
            
            extra_lora: Load LoRA weights. Supports Replicate models in the format <owner>/<username> or <owner>/<username>/<version>, HuggingFace URLs in the format huggingface.co/<owner>/<model-name>, CivitAI URLs in the format civitai.com/models/<id>[/<model-name>], or arbitrary .safetensors URLs from the Internet. For example, 'fofr/flux-pixar-cars' Optional.
            
            replicate_weights: Load LoRA weights. Supports Replicate models in the format <owner>/<username> or <owner>/<username>/<version>, HuggingFace URLs in the format huggingface.co/<owner>/<model-name>, CivitAI URLs in the format civitai.com/models/<id>[/<model-name>], or arbitrary .safetensors URLs from the Internet. For example, 'fofr/flux-pixar-cars' Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, model=model, go_fast=go_fast, lora_scale=lora_scale, megapixels=megapixels, num_outputs=num_outputs, aspect_ratio=aspect_ratio, output_format=output_format, guidance_scale=guidance_scale, output_quality=output_quality, prompt_strength=prompt_strength, extra_lora_scale=extra_lora_scale, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, mask=mask, seed=seed, image=image, width=width, height=height, extra_lora=extra_lora, replicate_weights=replicate_weights, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class sdxl_controlnet(FastClient):
    """
    Generated client for lucataco/sdxl-controlnet
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="53f34abc-e7b4-48e9-87ca-a3e4caf037c4", api_key=api_key)
    
    def predictions(self, seed: int = 0, prompt: str = 'aerial view, a futuristic research complex in a bright foggy jungle, hard lighting', condition_scale: float = 0.5, negative_prompt: str = 'low quality, bad quality, sketches', num_inference_steps: int = 50, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Random seed. Set to 0 to randomize the seed Defaults to 0.
            
            prompt: Input prompt Defaults to 'aerial view, a futuristic research complex in a bright foggy jungle, hard lighting'.
            
            condition_scale: controlnet conditioning scale for generalization Defaults to 0.5.
            
            negative_prompt: Input Negative Prompt Defaults to 'low quality, bad quality, sketches'.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            image: Input image for img2img or inpaint mode Optional.
            
        """
        return self.submit_job("/predictions", seed=seed, prompt=prompt, condition_scale=condition_scale, negative_prompt=negative_prompt, num_inference_steps=num_inference_steps, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.andreasjansson.blip_2 import blip_2
from socaity.sdk.replicate.andreasjansson.cantable_diffuguesion import cantable_diffuguesion
from socaity.sdk.replicate.andreasjansson.clip_features import clip_features
from socaity.sdk.replicate.andreasjansson.flux_goo import flux_goo
from socaity.sdk.replicate.andreasjansson.flux_me import flux_me
from socaity.sdk.replicate.andreasjansson.flux_shapes import flux_shapes
from socaity.sdk.replicate.andreasjansson.illusion import illusion
from socaity.sdk.replicate.andreasjansson.llama_2_13b_embeddings import llama_2_13b_embeddings
from socaity.sdk.replicate.andreasjansson.music_inpainting_bert import music_inpainting_bert
from socaity.sdk.replicate.andreasjansson.musicgen_looper import musicgen_looper
from socaity.sdk.replicate.andreasjansson.stable_diffusion_animation import stable_diffusion_animation
from socaity.sdk.replicate.andreasjansson.tile_morph import tile_morph
from socaity.sdk.replicate.andreasjansson.wan_1_3b_inpaint import wan_1_3b_inpaint


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class kandinsky_2_1(FastClient):
    """
    Generated client for ai-forever/kandinsky-2-1
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="89ca03f9-0f9c-4a7a-b45e-a3365b7e02a6", api_key=api_key)
    
    def predictions(self, task: str = 'text2img', width: int = 512, height: int = 512, prompt: str = 'A alien cheeseburger creature eating itself, claymation, cinematic, moody lighting', strength: float = 0.3, num_outputs: int = 1, guidance_scale: float = 4.0, negative_prompt: str = 'low quality, bad quality', num_steps_prior: int = 25, num_inference_steps: int = 100, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            task: Choose a task Defaults to 'text2img'.
            
            width: Width of output image. Reduce the seeting if hits memory limits Defaults to 512.
            
            height: Height of output image. Reduce the seeting if hits memory limits Defaults to 512.
            
            prompt: Provide input prompt Defaults to 'A alien cheeseburger creature eating itself, claymation, cinematic, moody lighting'.
            
            strength: indicates how much to transform the input iamge, valid for text_guided_img2img task. Defaults to 0.3.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 4.0.
            
            negative_prompt: Specify things to not see in the output for text2img and text_guided_img2img tasks Defaults to 'low quality, bad quality'.
            
            num_steps_prior: Number of denoising steps in prior Defaults to 25.
            
            num_inference_steps: Number of denoising steps Defaults to 100.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for text_guided_img2img task Optional.
            
        """
        return self.submit_job("/predictions", task=task, width=width, height=height, prompt=prompt, strength=strength, num_outputs=num_outputs, guidance_scale=guidance_scale, negative_prompt=negative_prompt, num_steps_prior=num_steps_prior, num_inference_steps=num_inference_steps, seed=seed, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class pheme(FastClient):
    """
    Generated client for lucataco/pheme
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="d0982aab-41ef-4ca8-ab52-cb176dca6f94", api_key=api_key)
    
    def predictions(self, top_k: int = 210, voice: str = 'male_voice', prompt: str = 'I gotta say, I would never expect that to happen!', temperature: float = 0.7, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            top_k: Top k Defaults to 210.
            
            voice: Voice to use Defaults to 'male_voice'.
            
            prompt: Input text Defaults to 'I gotta say, I would never expect that to happen!'.
            
            temperature: Temperature Defaults to 0.7.
            
        """
        return self.submit_job("/predictions", top_k=top_k, voice=voice, prompt=prompt, temperature=temperature, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class cantable_diffuguesion(FastClient):
    """
    Generated client for andreasjansson/cantable-diffuguesion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="6dcd3da7-fc2f-44b5-b7f6-d5a22712f195", api_key=api_key)
    
    def predictions(self, seed: int = -1, tempo: float = 90.0, melody: str = '', duration: int = 32, return_mp3: bool = True, return_midi: bool = True, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Random seed. Random if seed == -1 Defaults to -1.
            
            tempo: Tempo in quarter notes per minute Defaults to 90.0.
            
            melody: Melody in tinyNotation format. Accepts ? for inpainting a single note, and ?* for inpainting between two melodic parts Defaults to ''.
            
            duration: Duration in quarter notes Defaults to 32.
            
            return_mp3: Return mp3 audio Defaults to True.
            
            return_midi: Return midi Defaults to True.
            
        """
        return self.submit_job("/predictions", seed=seed, tempo=tempo, melody=melody, duration=duration, return_mp3=return_mp3, return_midi=return_midi, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class gfpgan_video(FastClient):
    """
    Generated client for pbarker/gfpgan-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="3454b77b-92fa-4578-9f67-afc287ca389a", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], scale: float = 2.0, version: str = 'v1.4', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input
            
            scale: Rescaling factor Defaults to 2.0.
            
            version: GFPGAN version. v1.3: better quality. v1.4: more details and better identity. Defaults to 'v1.4'.
            
        """
        return self.submit_job("/predictions", video=video, scale=scale, version=version, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Any

from media_toolkit import AudioFile, MediaFile


class speechcraft(FastClient):
    """
    Create audio from text, clone voices and use them. Convert voice2voice. Generative text-to-audio Bark model.
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ee0af319-70d4-4171-9954-c24ad01b3e05", api_key=api_key)
    
    def text2voice(self, text: str, voice: Union[Any, MediaFile, str, bytes] = 'en_speaker_3', fine_temp: float = 0.5, coarse_temp: float = 0.7, coarse_top_k: int = 50, coarse_top_p: float = 0.95, semantic_temp: float = 0.7, semantic_top_k: int = 50, semantic_top_p: float = 0.95, **kwargs) -> APISeex:
        """
        :param text: the text to be converted
        :param voice: the name of the voice to be used. Uses the pretrained voices which are stored in models/speakers folder.
            It is also possible to provide a full path.
        :return: the audio file as bytes
        
        """
        return self.submit_job("/text2voice", text=text, voice=voice, fine_temp=fine_temp, coarse_temp=coarse_temp, coarse_top_k=coarse_top_k, coarse_top_p=coarse_top_p, semantic_temp=semantic_temp, semantic_top_k=semantic_top_k, semantic_top_p=semantic_top_p, **kwargs)
    
    def voice2voice(self, audio_file: Union[AudioFile, Any, MediaFile, str, bytes], temp: float = 0.7, voice_name: Union[Any, MediaFile, str, bytes] = 'en_speaker_3', **kwargs) -> APISeex:
        """
        :param audio_file: the audio file as bytes 5-20s is good length
        :param voice_name: the new of the voice to convert to; or the voice embedding. String or MediaFile.
        :param temp: generation temperature (1.0 more diverse, 0.0 more conservative)
        :return: the converted audio file as bytes
        
        """
        return self.submit_job("/voice2voice", audio_file=audio_file, temp=temp, voice_name=voice_name, **kwargs)
    
    def voice2embedding(self, audio_file: Union[AudioFile, Any, MediaFile, str, bytes], save: bool = False, voice_name: str = 'new_speaker', **kwargs) -> APISeex:
        """
        :param audio_file: the audio file as bytes 5-20s is good length
        :param voice_name: how the new voice / embedding is named
        :param save: if the embedding should be saved in the voice dir for reusage.
            Note: depending on the server settings this might not be allowed
        :return: the voice embedding as bytes
        
        """
        return self.submit_job("/voice2embedding", audio_file=audio_file, save=save, voice_name=voice_name, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = text2voice
    __call__ = text2voice


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class wan2_1_with_lora(FastClient):
    """
    Generated client for fofr/wan2-1-with-lora
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="bc1e7c1e-2347-4085-b329-a03904a4514e", api_key=api_key)
    
    def predictions(self, prompt: str, model: str = '14b', frames: int = 81, fast_mode: str = 'Balanced', resolution: str = '480p', aspect_ratio: str = '16:9', sample_shift: float = 8.0, sample_steps: int = 30, negative_prompt: str = '', lora_strength_clip: float = 1.0, sample_guide_scale: float = 5.0, lora_strength_model: float = 1.0, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, lora_url: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Text prompt for video generation
            
            model: The model to use. 1.3b is faster, but 14b is better quality. A LORA either works with 1.3b or 14b, depending on the version it was trained on. Defaults to '14b'.
            
            frames: The number of frames to generate (1 to 5 seconds) Defaults to 81.
            
            fast_mode: Speed up generation with different levels of acceleration. Faster modes may degrade quality somewhat. The speedup is dependent on the content, so different videos may see different speedups. Defaults to 'Balanced'.
            
            resolution: The resolution of the video. 720p is not supported for 1.3b. Defaults to '480p'.
            
            aspect_ratio: The aspect ratio of the video. 16:9, 9:16, 1:1, etc. Defaults to '16:9'.
            
            sample_shift: Sample shift factor Defaults to 8.0.
            
            sample_steps: Number of generation steps. Fewer steps means faster generation, at the expensive of output quality. 30 steps is sufficient for most prompts Defaults to 30.
            
            negative_prompt: Things you do not want to see in your video Defaults to ''.
            
            lora_strength_clip: Strength of the LORA applied to the CLIP model. 0.0 is no LORA. Defaults to 1.0.
            
            sample_guide_scale: Higher guide scale makes prompt adherence better, but can reduce variation Defaults to 5.0.
            
            lora_strength_model: Strength of the LORA applied to the model. 0.0 is no LORA. Defaults to 1.0.
            
            seed: Set a seed for reproducibility. Random by default. Optional.
            
            image: Image to use as a starting frame for image to video generation. Optional.
            
            lora_url: Optional: The URL of a LORA to use Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, model=model, frames=frames, fast_mode=fast_mode, resolution=resolution, aspect_ratio=aspect_ratio, sample_shift=sample_shift, sample_steps=sample_steps, negative_prompt=negative_prompt, lora_strength_clip=lora_strength_clip, sample_guide_scale=sample_guide_scale, lora_strength_model=lora_strength_model, seed=seed, image=image, lora_url=lora_url, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class stable_diffusion_inpainting(FastClient):
    """
    Generated client for stability-ai/stable-diffusion-inpainting
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="d5e66f27-1249-4db2-9f73-651c156399ad", api_key=api_key)
    
    def predictions(self, mask: Union[MediaFile, str, bytes], image: Union[MediaFile, str, bytes], width: int = 512, height: int = 512, prompt: str = 'a vision of paradise. unreal engine', scheduler: str = 'DPMSolverMultistep', num_outputs: int = 1, guidance_scale: float = 7.5, num_inference_steps: int = 50, disable_safety_checker: bool = False, seed: Optional[int] = None, negative_prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            mask: Black and white image to use as mask for inpainting over the image provided. White pixels are inpainted and black pixels are preserved.
            
            image: Initial image to generate variations of. Will be resized to height x width
            
            width: Width of generated image in pixels. Needs to be a multiple of 64 Defaults to 512.
            
            height: Height of generated image in pixels. Needs to be a multiple of 64 Defaults to 512.
            
            prompt: Input prompt Defaults to 'a vision of paradise. unreal engine'.
            
            scheduler: Choose a scheduler. Defaults to 'DPMSolverMultistep'.
            
            num_outputs: Number of images to generate. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API. See [https://replicate.com/docs/how-does-replicate-work#safety](https://replicate.com/docs/how-does-replicate-work#safety) Defaults to False.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            negative_prompt: Specify things to not see in the output Optional.
            
        """
        return self.submit_job("/predictions", mask=mask, image=image, width=width, height=height, prompt=prompt, scheduler=scheduler, num_outputs=num_outputs, guidance_scale=guidance_scale, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, seed=seed, negative_prompt=negative_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class whisperx_video_transcribe(FastClient):
    """
    Generated client for adidoes/whisperx-video-transcribe
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="41f4ed07-3d37-4dde-9458-09f1e308d8f1", api_key=api_key)
    
    def predictions(self, url: str, debug: bool = False, batch_size: int = 16, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            url: Video URL. View supported sites https://dub.sh/supportedsites
            
            debug: Print out memory usage information. Defaults to False.
            
            batch_size: Parallelization of input audio transcription Defaults to 16.
            
        """
        return self.submit_job("/predictions", url=url, debug=debug, batch_size=batch_size, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class frames_to_video(FastClient):
    """
    Generated client for fofr/frames-to-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="e288c787-b473-4e4c-9eff-1073736a7c9b", api_key=api_key)
    
    def predictions(self, fps: float = 24.0, frames_zip: Optional[Union[MediaFile, str, bytes]] = None, frames_urls: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            fps: Number of frames per second of video Defaults to 24.0.
            
            frames_zip: ZIP file containing frames Optional.
            
            frames_urls: Newline-separated URLs of frames to combine into a video Optional.
            
        """
        return self.submit_job("/predictions", fps=fps, frames_zip=frames_zip, frames_urls=frames_urls, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class tortoise_tts(FastClient):
    """
    Generated client for afiaka87/tortoise-tts
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="82a76d4e-73a1-4e7e-94d6-0e6f4b81519e", api_key=api_key)
    
    def predictions(self, seed: int = 0, text: str = 'The expressiveness of autoregressive transformers is literally nuts! I absolutely adore them.', preset: str = 'fast', voice_a: str = 'random', voice_b: str = 'disabled', voice_c: str = 'disabled', cvvp_amount: float = 0.0, custom_voice: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Random seed which can be used to reproduce results. Defaults to 0.
            
            text: Text to speak. Defaults to 'The expressiveness of autoregressive transformers is literally nuts! I absolutely adore them.'.
            
            preset: Which voice preset to use. See the documentation for more information. Defaults to 'fast'.
            
            voice_a: Selects the voice to use for generation. Use `random` to select a random voice. Use `custom_voice` to use a custom voice. Defaults to 'random'.
            
            voice_b: (Optional) Create new voice from averaging the latents for `voice_a`, `voice_b` and `voice_c`. Use `disabled` to disable voice mixing. Defaults to 'disabled'.
            
            voice_c: (Optional) Create new voice from averaging the latents for `voice_a`, `voice_b` and `voice_c`. Use `disabled` to disable voice mixing. Defaults to 'disabled'.
            
            cvvp_amount: How much the CVVP model should influence the output. Increasing this can in some cases reduce the likelyhood of multiple speakers. Defaults to 0 (disabled) Defaults to 0.0.
            
            custom_voice: (Optional) Create a custom voice based on an mp3 file of a speaker. Audio should be at least 15 seconds, only contain one speaker, and be in mp3 format. Overrides the `voice_a` input. Optional.
            
        """
        return self.submit_job("/predictions", seed=seed, text=text, preset=preset, voice_a=voice_a, voice_b=voice_b, voice_c=voice_c, cvvp_amount=cvvp_amount, custom_voice=custom_voice, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.tokaito14.art import art
from socaity.sdk.replicate.tokaito14.fullbody import fullbody
from socaity.sdk.replicate.tokaito14.laura import laura
from socaity.sdk.replicate.tokaito14.portrait import portrait


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class clothing_segmentation(FastClient):
    """
    Generated client for naklecha/clothing-segmentation
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="bb3f71e6-4cfa-4d75-a39c-ad86f5816ef2", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], clothing: str = 'topwear', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image to in-paint. The image will be center cropped and resized to size 512*512.
            
            clothing: This value should be one of the following - [topwear, bottomwear] Defaults to 'topwear'.
            
        """
        return self.submit_job("/predictions", image=image, clothing=clothing, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import List, Union, Any

from media_toolkit import MediaFile


class trellis(FastClient):
    """
    Generated client for firtoz/trellis
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f5e519f8-a442-42b7-9a1e-b4addb1d3ffa", api_key=api_key)
    
    def predictions(self, images: Union[List[Any], MediaFile, str, bytes], seed: int = 0, texture_size: int = 1024, mesh_simplify: float = 0.95, generate_color: bool = True, generate_model: bool = False, randomize_seed: bool = True, generate_normal: bool = False, save_gaussian_ply: bool = False, ss_sampling_steps: int = 12, slat_sampling_steps: int = 12, return_no_background: bool = False, ss_guidance_strength: float = 7.5, slat_guidance_strength: float = 3.0, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            images: List of input images to generate 3D asset from
            
            seed: Random seed for generation Defaults to 0.
            
            texture_size: GLB Extraction - Texture Size (only used if generate_model=True) Defaults to 1024.
            
            mesh_simplify: GLB Extraction - Mesh Simplification (only used if generate_model=True) Defaults to 0.95.
            
            generate_color: Generate color video render Defaults to True.
            
            generate_model: Generate 3D model file (GLB) Defaults to False.
            
            randomize_seed: Randomize seed Defaults to True.
            
            generate_normal: Generate normal video render Defaults to False.
            
            save_gaussian_ply: Save Gaussian point cloud as PLY file Defaults to False.
            
            ss_sampling_steps: Stage 1: Sparse Structure Generation - Sampling Steps Defaults to 12.
            
            slat_sampling_steps: Stage 2: Structured Latent Generation - Sampling Steps Defaults to 12.
            
            return_no_background: Return the preprocessed images without background Defaults to False.
            
            ss_guidance_strength: Stage 1: Sparse Structure Generation - Guidance Strength Defaults to 7.5.
            
            slat_guidance_strength: Stage 2: Structured Latent Generation - Guidance Strength Defaults to 3.0.
            
        """
        return self.submit_job("/predictions", images=images, seed=seed, texture_size=texture_size, mesh_simplify=mesh_simplify, generate_color=generate_color, generate_model=generate_model, randomize_seed=randomize_seed, generate_normal=generate_normal, save_gaussian_ply=save_gaussian_ply, ss_sampling_steps=ss_sampling_steps, slat_sampling_steps=slat_sampling_steps, return_no_background=return_no_background, ss_guidance_strength=ss_guidance_strength, slat_guidance_strength=slat_guidance_strength, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class musicgen(FastClient):
    """
    Generated client for charlesmccarthy/musicgen
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="6b947fb9-cbff-427b-9df8-517be1a5673a", api_key=api_key)
    
    def predictions(self, top_k: int = 250, top_p: float = 0.0, duration: int = 8, temperature: float = 1.0, continuation: bool = False, model_version: str = 'stereo-melody-large', output_format: str = 'wav', continuation_start: int = 0, multi_band_diffusion: bool = False, normalization_strategy: str = 'loudness', classifier_free_guidance: int = 3, seed: Optional[int] = None, prompt: Optional[str] = None, input_audio: Optional[Union[MediaFile, str, bytes]] = None, continuation_end: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            top_k: Reduces sampling to the k most likely tokens. Defaults to 250.
            
            top_p: Reduces sampling to tokens with cumulative probability of p. When set to  `0` (default), top_k sampling is used. Defaults to 0.0.
            
            duration: Duration of the generated audio in seconds. Defaults to 8.
            
            temperature: Controls the 'conservativeness' of the sampling process. Higher temperature means more diversity. Defaults to 1.0.
            
            continuation: If `True`, generated music will continue from `input_audio`. Otherwise, generated music will mimic `input_audio`'s melody. Defaults to False.
            
            model_version: Model to use for generation Defaults to 'stereo-melody-large'.
            
            output_format: Output format for generated audio. Defaults to 'wav'.
            
            continuation_start: Start time of the audio file to use for continuation. Defaults to 0.
            
            multi_band_diffusion: If `True`, the EnCodec tokens will be decoded with MultiBand Diffusion. Only works with non-stereo models. Defaults to False.
            
            normalization_strategy: Strategy for normalizing audio. Defaults to 'loudness'.
            
            classifier_free_guidance: Increases the influence of inputs on the output. Higher values produce lower-varience outputs that adhere more closely to inputs. Defaults to 3.
            
            seed: Seed for random number generator. If None or -1, a random seed will be used. Optional.
            
            prompt: A description of the music you want to generate. Optional.
            
            input_audio: An audio file that will influence the generated music. If `continuation` is `True`, the generated music will be a continuation of the audio file. Otherwise, the generated music will mimic the audio file's melody. Optional.
            
            continuation_end: End time of the audio file to use for continuation. If -1 or None, will default to the end of the audio clip. Optional.
            
        """
        return self.submit_job("/predictions", top_k=top_k, top_p=top_p, duration=duration, temperature=temperature, continuation=continuation, model_version=model_version, output_format=output_format, continuation_start=continuation_start, multi_band_diffusion=multi_band_diffusion, normalization_strategy=normalization_strategy, classifier_free_guidance=classifier_free_guidance, seed=seed, prompt=prompt, input_audio=input_audio, continuation_end=continuation_end, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class latent_consistency_model(FastClient):
    """
    Generated client for fofr/latent-consistency-model
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="257ba909-831f-4c7c-990e-7aee51b68eb1", api_key=api_key)
    
    def predictions(self, width: int = 768, height: int = 768, prompt: str = 'Self-portrait oil painting, a beautiful cyborg with golden hair, 8k', num_images: int = 1, guidance_scale: float = 8.0, archive_outputs: bool = False, prompt_strength: float = 0.8, sizing_strategy: str = 'width/height', lcm_origin_steps: int = 50, canny_low_threshold: float = 100.0, num_inference_steps: int = 8, canny_high_threshold: float = 200.0, control_guidance_end: float = 1.0, control_guidance_start: float = 0.0, disable_safety_checker: bool = False, controlnet_conditioning_scale: float = 2.0, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, control_image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image. Lower if out of memory Defaults to 768.
            
            height: Height of output image. Lower if out of memory Defaults to 768.
            
            prompt: For multiple prompts, enter each on a new line. Defaults to 'Self-portrait oil painting, a beautiful cyborg with golden hair, 8k'.
            
            num_images: Number of images per prompt Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 8.0.
            
            archive_outputs: Option to archive the output images Defaults to False.
            
            prompt_strength: Prompt strength when using img2img. 1.0 corresponds to full destruction of information in image Defaults to 0.8.
            
            sizing_strategy: Decide how to resize images – use width/height, resize based on input image or control image Defaults to 'width/height'.
            
            lcm_origin_steps: lcm_origin_steps Defaults to 50.
            
            canny_low_threshold: Canny low threshold Defaults to 100.0.
            
            num_inference_steps: Number of denoising steps. Recommend 1 to 8 steps. Defaults to 8.
            
            canny_high_threshold: Canny high threshold Defaults to 200.0.
            
            control_guidance_end: Controlnet end Defaults to 1.0.
            
            control_guidance_start: Controlnet start Defaults to 0.0.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API Defaults to False.
            
            controlnet_conditioning_scale: Controlnet conditioning scale Defaults to 2.0.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for img2img Optional.
            
            control_image: Image for controlnet conditioning Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, num_images=num_images, guidance_scale=guidance_scale, archive_outputs=archive_outputs, prompt_strength=prompt_strength, sizing_strategy=sizing_strategy, lcm_origin_steps=lcm_origin_steps, canny_low_threshold=canny_low_threshold, num_inference_steps=num_inference_steps, canny_high_threshold=canny_high_threshold, control_guidance_end=control_guidance_end, control_guidance_start=control_guidance_start, disable_safety_checker=disable_safety_checker, controlnet_conditioning_scale=controlnet_conditioning_scale, seed=seed, image=image, control_image=control_image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.ai_forever.kandinsky_2 import kandinsky_2
from socaity.sdk.replicate.ai_forever.kandinsky_2_1 import kandinsky_2_1
from socaity.sdk.replicate.ai_forever.kandinsky_2_2 import kandinsky_2_2


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class musicgen_stereo_chord(FastClient):
    """
    Generated client for sakemin/musicgen-stereo-chord
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="4d80c2dc-a76b-447f-bf79-e677161b6d6c", api_key=api_key)
    
    def predictions(self, top_k: int = 250, top_p: float = 0.0, duration: int = 8, time_sig: str = '4/4', audio_start: int = 0, temperature: float = 1.0, continuation: bool = False, model_version: str = 'stereo-chord-large', output_format: str = 'wav', chroma_coefficient: float = 1.0, multi_band_diffusion: bool = False, normalization_strategy: str = 'loudness', classifier_free_guidance: int = 3, bpm: Optional[float] = None, seed: Optional[int] = None, prompt: Optional[str] = None, audio_end: Optional[int] = None, text_chords: Optional[str] = None, audio_chords: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            top_k: Reduces sampling to the k most likely tokens. Defaults to 250.
            
            top_p: Reduces sampling to tokens with cumulative probability of p. When set to  `0` (default), top_k sampling is used. Defaults to 0.0.
            
            duration: Duration of the generated audio in seconds. Defaults to 8.
            
            time_sig: Time signature value for the generate output. `text_chords` will be processed based on this value. This will be appended at the end of `prompt`. Defaults to '4/4'.
            
            audio_start: Start time of the audio file to use for chord conditioning. Defaults to 0.
            
            temperature: Controls the 'conservativeness' of the sampling process. Higher temperature means more diversity. Defaults to 1.0.
            
            continuation: If `True`, generated music will continue from `audio_chords`. If chord conditioning, this is only possible when the chord condition is given with `text_chords`. If `False`, generated music will mimic `audio_chords`'s chord. Defaults to False.
            
            model_version: Model type. Select `fine-tuned` if you trained the model into your own repository. Defaults to 'stereo-chord-large'.
            
            output_format: Output format for generated audio. Defaults to 'wav'.
            
            chroma_coefficient: Coefficient value multiplied to multi-hot chord chroma. Defaults to 1.0.
            
            multi_band_diffusion: If `True`, the EnCodec tokens will be decoded with MultiBand Diffusion. Not compatible with stereo models. Defaults to False.
            
            normalization_strategy: Strategy for normalizing audio. Defaults to 'loudness'.
            
            classifier_free_guidance: Increases the influence of inputs on the output. Higher values produce lower-varience outputs that adhere more closely to inputs. Defaults to 3.
            
            bpm: BPM condition for the generated output. `text_chords` will be processed based on this value. This will be appended at the end of `prompt`. Optional.
            
            seed: Seed for random number generator. If `None` or `-1`, a random seed will be used. Optional.
            
            prompt: A description of the music you want to generate. Optional.
            
            audio_end: End time of the audio file to use for chord conditioning. If None, will default to the end of the audio clip. Optional.
            
            text_chords: A text based chord progression condition. Single uppercase alphabet character(eg. `C`) is considered as a major chord. Chord attributes like(`maj`, `min`, `dim`, `aug`, `min6`, `maj6`, `min7`, `minmaj7`, `maj7`, `7`, `dim7`, `hdim7`, `sus2` and `sus4`) can be added to the root alphabet character after `:`.(eg. `A:min7`) Each chord token splitted by `SPACE` is allocated to a single bar. If more than one chord must be allocated to a single bar, cluster the chords adding with `,` without any `SPACE`.(eg. `C,C:7 G, E:min A:min`) You must choose either only one of `audio_chords` below or `text_chords`. Optional.
            
            audio_chords: An audio file that will condition the chord progression. You must choose only one among `audio_chords` or `text_chords` above. Optional.
            
        """
        return self.submit_job("/predictions", top_k=top_k, top_p=top_p, duration=duration, time_sig=time_sig, audio_start=audio_start, temperature=temperature, continuation=continuation, model_version=model_version, output_format=output_format, chroma_coefficient=chroma_coefficient, multi_band_diffusion=multi_band_diffusion, normalization_strategy=normalization_strategy, classifier_free_guidance=classifier_free_guidance, bpm=bpm, seed=seed, prompt=prompt, audio_end=audio_end, text_chords=text_chords, audio_chords=audio_chords, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.lucataco.ace_step import ace_step
from socaity.sdk.replicate.lucataco.controlnet_tile import controlnet_tile
from socaity.sdk.replicate.lucataco.csm_1b import csm_1b
from socaity.sdk.replicate.lucataco.deep3d import deep3d
from socaity.sdk.replicate.lucataco.demofusion_enhance import demofusion_enhance
from socaity.sdk.replicate.lucataco.depth_anything_video import depth_anything_video
from socaity.sdk.replicate.lucataco.dreamshaper_xl_turbo import dreamshaper_xl_turbo
from socaity.sdk.replicate.lucataco.florence_2_large import florence_2_large
from socaity.sdk.replicate.lucataco.flux_queso import flux_queso
from socaity.sdk.replicate.lucataco.flux_syd_mead import flux_syd_mead
from socaity.sdk.replicate.lucataco.flux_vlta import flux_vlta
from socaity.sdk.replicate.lucataco.flux_watercolor import flux_watercolor
from socaity.sdk.replicate.lucataco.frame_extractor import frame_extractor
from socaity.sdk.replicate.lucataco.hotshot_xl import hotshot_xl
from socaity.sdk.replicate.lucataco.img_and_audio2video import img_and_audio2video
from socaity.sdk.replicate.lucataco.magnet import magnet
from socaity.sdk.replicate.lucataco.merge_img import merge_img
from socaity.sdk.replicate.lucataco.mvsep_mdx23_music_separation import mvsep_mdx23_music_separation
from socaity.sdk.replicate.lucataco.nomic_embed_text_v1 import nomic_embed_text_v1
from socaity.sdk.replicate.lucataco.nsfw_video_detection import nsfw_video_detection
from socaity.sdk.replicate.lucataco.open_dalle_v1_1 import open_dalle_v1_1
from socaity.sdk.replicate.lucataco.orpheus_3b_0_1_ft import orpheus_3b_0_1_ft
from socaity.sdk.replicate.lucataco.pasd_magnify import pasd_magnify
from socaity.sdk.replicate.lucataco.pheme import pheme
from socaity.sdk.replicate.lucataco.phi_2 import phi_2
from socaity.sdk.replicate.lucataco.phixtral_2x2_8 import phixtral_2x2_8
from socaity.sdk.replicate.lucataco.pixart_xl_2 import pixart_xl_2
from socaity.sdk.replicate.lucataco.qwen1_5_72b import qwen1_5_72b
from socaity.sdk.replicate.lucataco.qwen1_5_7b import qwen1_5_7b
from socaity.sdk.replicate.lucataco.real_esrgan_video import real_esrgan_video
from socaity.sdk.replicate.lucataco.realistic_vision_v5 import realistic_vision_v5
from socaity.sdk.replicate.lucataco.realistic_vision_v5_1 import realistic_vision_v5_1
from socaity.sdk.replicate.lucataco.realvisxl2_lcm import realvisxl2_lcm
from socaity.sdk.replicate.lucataco.realvisxl_v2_0 import realvisxl_v2_0
from socaity.sdk.replicate.lucataco.rembg_video import rembg_video
from socaity.sdk.replicate.lucataco.sdxl_controlnet import sdxl_controlnet
from socaity.sdk.replicate.lucataco.singing_voice_conversion import singing_voice_conversion
from socaity.sdk.replicate.lucataco.snowflake_arctic_embed_l import snowflake_arctic_embed_l
from socaity.sdk.replicate.lucataco.ssd_1b import ssd_1b
from socaity.sdk.replicate.lucataco.stable_diffusion_x4_upscaler import stable_diffusion_x4_upscaler
from socaity.sdk.replicate.lucataco.video_merge import video_merge
from socaity.sdk.replicate.lucataco.video_split import video_split
from socaity.sdk.replicate.lucataco.wan_2_1_1_3b_vid2vid import wan_2_1_1_3b_vid2vid
from socaity.sdk.replicate.lucataco.xtts_v2 import xtts_v2


from fastsdk import FastClient, APISeex

class cogvideox_5b(FastClient):
    """
    Generated client for cuuupid/cogvideox-5b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="579d6489-362b-4a37-b0fd-9ef14b7c8882", api_key=api_key)
    
    def predictions(self, prompt: str, seed: int = 42, steps: int = 50, guidance: float = 6.0, num_outputs: int = 1, extend_prompt: bool = True, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt
            
            seed: Seed for reproducibility. Defaults to 42.
            
            steps: # of inference steps, more steps can improve quality. Defaults to 50.
            
            guidance: The scale for classifier-free guidance, higher guidance can improve adherence to your prompt. Defaults to 6.0.
            
            num_outputs: # of output videos Defaults to 1.
            
            extend_prompt: If enabled, will use GLM-4 to make the prompt long (as intended for CogVideoX). Defaults to True.
            
        """
        return self.submit_job("/predictions", prompt=prompt, seed=seed, steps=steps, guidance=guidance, num_outputs=num_outputs, extend_prompt=extend_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class hotshot_xl(FastClient):
    """
    Generated client for lucataco/hotshot-xl
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="5ceba273-ccc6-4b04-b3fe-bc7a254e8456", api_key=api_key)
    
    def predictions(self, mp4: bool = False, steps: int = 30, width: int = 672, height: int = 384, prompt: str = 'a camel smoking a cigarette, hd, high quality', scheduler: str = 'EulerAncestralDiscreteScheduler', negative_prompt: str = 'blurry', seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            mp4: Save as mp4, False for GIF Defaults to False.
            
            steps: Number of denoising steps Defaults to 30.
            
            width: Width of the output Defaults to 672.
            
            height: Height of the output Defaults to 384.
            
            prompt: Input prompt Defaults to 'a camel smoking a cigarette, hd, high quality'.
            
            scheduler: Select a Scheduler Defaults to 'EulerAncestralDiscreteScheduler'.
            
            negative_prompt: Negative prompt Defaults to 'blurry'.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", mp4=mp4, steps=steps, width=width, height=height, prompt=prompt, scheduler=scheduler, negative_prompt=negative_prompt, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class looptest(FastClient):
    """
    Generated client for allenhung1025/looptest
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2389def2-9430-486d-afbd-2cdd0631d659", api_key=api_key)
    
    def predictions(self, seed: int = -1, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Set seed, -1 for random Defaults to -1.
            
        """
        return self.submit_job("/predictions", seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class yi_34b_chat(FastClient):
    """
    Generated client for -01-ai/yi-34b-chat
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="6a87dce9-1dbe-4486-a56e-21fe9928e6a7", api_key=api_key)
    
    def predictions(self, prompt: str, top_k: int = 50, top_p: float = 0.8, temperature: float = 0.3, max_new_tokens: int = 1024, prompt_template: str = '<|im_start|>system\nYou are a helpful assistant<|im_end|>\n<|im_start|>user\n{prompt}<|im_end|>\n<|im_start|>assistant\n', repetition_penalty: float = 1.2, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            prompt: prompt
            
            top_k: The number of highest probability tokens to consider for generating the output. If > 0, only keep the top k tokens with highest probability (top-k filtering). Defaults to 50.
            
            top_p: A probability threshold for generating the output. If < 1.0, only keep the top tokens with cumulative probability >= top_p (nucleus filtering). Nucleus filtering is described in Holtzman et al. (http://arxiv.org/abs/1904.09751). Defaults to 0.8.
            
            temperature: The value used to modulate the next token probabilities. Defaults to 0.3.
            
            max_new_tokens: The maximum number of tokens the model should generate as output. Defaults to 1024.
            
            prompt_template: The template used to format the prompt. The input prompt is inserted into the template using the `{prompt}` placeholder. Defaults to '<|im_start|>system\nYou are a helpful assistant<|im_end|>\n<|im_start|>user\n{prompt}<|im_end|>\n<|im_start|>assistant\n'.
            
            repetition_penalty: Repetition penalty Defaults to 1.2.
            
        """
        return self.submit_job("/predictions", prompt=prompt, top_k=top_k, top_p=top_p, temperature=temperature, max_new_tokens=max_new_tokens, prompt_template=prompt_template, repetition_penalty=repetition_penalty, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class image_urls_to_video(FastClient):
    """
    Generated client for chigozienri/image-urls-to-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ecd3c3af-392c-4b48-860e-87247711b938", api_key=api_key)
    
    def predictions(self, image_urls: str, fps: float = 4.0, mp4: bool = False, output_zip: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image_urls: A comma-separated list of input urls
            
            fps: Frames per second of output video Defaults to 4.0.
            
            mp4: Returns .mp4 if true or .gif if false Defaults to False.
            
            output_zip: Also returns a zip of the input images if true Defaults to False.
            
        """
        return self.submit_job("/predictions", image_urls=image_urls, fps=fps, mp4=mp4, output_zip=output_zip, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.adirik.e5_mistral_7b_instruct import e5_mistral_7b_instruct
from socaity.sdk.replicate.adirik.flux_cinestill import flux_cinestill
from socaity.sdk.replicate.adirik.flux_fantasy_architecture import flux_fantasy_architecture
from socaity.sdk.replicate.adirik.grounding_dino import grounding_dino
from socaity.sdk.replicate.adirik.imagedream import imagedream
from socaity.sdk.replicate.adirik.interior_design import interior_design
from socaity.sdk.replicate.adirik.mamba_130m import mamba_130m
from socaity.sdk.replicate.adirik.mamba_1_4b import mamba_1_4b
from socaity.sdk.replicate.adirik.mamba_2_8b import mamba_2_8b
from socaity.sdk.replicate.adirik.mamba_2_8b_slimpj import mamba_2_8b_slimpj
from socaity.sdk.replicate.adirik.mamba_370m import mamba_370m
from socaity.sdk.replicate.adirik.mamba_790m import mamba_790m
from socaity.sdk.replicate.adirik.mvdream import mvdream
from socaity.sdk.replicate.adirik.owlvit_base_patch32 import owlvit_base_patch32
from socaity.sdk.replicate.adirik.realvisxl_v3_0_turbo import realvisxl_v3_0_turbo
from socaity.sdk.replicate.adirik.realvisxl_v4_0 import realvisxl_v4_0
from socaity.sdk.replicate.adirik.styletts2 import styletts2
from socaity.sdk.replicate.adirik.text2tex import text2tex
from socaity.sdk.replicate.adirik.texture import texture
from socaity.sdk.replicate.adirik.wonder3d import wonder3d


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class depth_anything_video(FastClient):
    """
    Generated client for lucataco/depth-anything-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="6b9644e4-0161-4dc8-bda5-aa76bf67233b", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], encoder: str = 'vits', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input video
            
            encoder: Model type Defaults to 'vits'.
            
        """
        return self.submit_job("/predictions", video=video, encoder=encoder, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class background_remover(FastClient):
    """
    Generated client for -851-labs/background-remover
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="41bbfe93-f999-4de3-b380-fabe0b960cb0", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], format: str = 'png', reverse: bool = False, threshold: float = 0.0, background_type: str = 'rgba', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            format: Output format (e.g., png, jpg). Defaults to png. Defaults to 'png'.
            
            reverse: If True, remove the foreground instead of the background. Defaults to False.
            
            threshold: Threshold for hard segmentation (0.0-1.0). If 0.0, uses soft alpha. Defaults to 0.0.
            
            background_type: Background type: 'rgba', 'map', 'green', 'white', [R,G,B] array, 'blur', 'overlay', or path to an image. Defaults to 'rgba'.
            
        """
        return self.submit_job("/predictions", image=image, format=format, reverse=reverse, threshold=threshold, background_type=background_type, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class videocrafter(FastClient):
    """
    Generated client for cjwbw/videocrafter
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="08be5d85-7e6f-418c-a99f-e46d51f39428", api_key=api_key)
    
    def predictions(self, prompt: str = 'With the style of van gogh, A young couple dances under the moonlight by the lake.', save_fps: int = 10, ddim_steps: int = 50, unconditional_guidance_scale: float = 12.0, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt for video generation. Defaults to 'With the style of van gogh, A young couple dances under the moonlight by the lake.'.
            
            save_fps: Frame per second for the generated video. Defaults to 10.
            
            ddim_steps: Number of denoising steps. Defaults to 50.
            
            unconditional_guidance_scale: Classifier-free guidance scale. Defaults to 12.0.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, save_fps=save_fps, ddim_steps=ddim_steps, unconditional_guidance_scale=unconditional_guidance_scale, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class xtts_v2(FastClient):
    """
    Generated client for lucataco/xtts-v2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f31156fb-c378-43f0-86a4-3bec755a5347", api_key=api_key)
    
    def predictions(self, speaker: Union[MediaFile, str, bytes], text: str = "Hi there, I'm your new voice clone. Try your best to upload quality audio", language: str = 'en', cleanup_voice: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            speaker: Original speaker audio (wav, mp3, m4a, ogg, or flv)
            
            text: Text to synthesize Defaults to "Hi there, I'm your new voice clone. Try your best to upload quality audio".
            
            language: Output language for the synthesised speech Defaults to 'en'.
            
            cleanup_voice: Whether to apply denoising to the speaker audio (microphone recordings) Defaults to False.
            
        """
        return self.submit_job("/predictions", speaker=speaker, text=text, language=language, cleanup_voice=cleanup_voice, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class mvsep_mdx23_music_separation(FastClient):
    """
    Generated client for lucataco/mvsep-mdx23-music-separation
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="dfc95e7b-bf4d-4f6b-ac10-fc8ee5177287", api_key=api_key)
    
    def predictions(self, audio: Union[MediaFile, str, bytes], **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio: Input Audio File
            
        """
        return self.submit_job("/predictions", audio=audio, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class stable_audio_open_1_0(FastClient):
    """
    Generated client for stackadoc/stable-audio-open-1-0
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="7e0dc562-8bcb-4ae7-b8ff-c97ace4a1c7f", api_key=api_key)
    
    def predictions(self, prompt: str, seed: int = -1, steps: int = 100, cfg_scale: float = 6.0, sigma_max: int = 500, sigma_min: float = 0.03, batch_size: int = 1, sampler_type: str = 'dpmpp-3m-sde', seconds_start: int = 0, seconds_total: int = 8, negative_prompt: str = '', init_noise_level: float = 1.0, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: prompt
            
            seed: seed Defaults to -1.
            
            steps: steps Defaults to 100.
            
            cfg_scale: cfg_scale Defaults to 6.0.
            
            sigma_max: sigma_max Defaults to 500.
            
            sigma_min: sigma_min Defaults to 0.03.
            
            batch_size: batch_size Defaults to 1.
            
            sampler_type: sampler_type Defaults to 'dpmpp-3m-sde'.
            
            seconds_start: seconds_start Defaults to 0.
            
            seconds_total: seconds_total Defaults to 8.
            
            negative_prompt: negative_prompt Defaults to ''.
            
            init_noise_level: init_noise_level Defaults to 1.0.
            
        """
        return self.submit_job("/predictions", prompt=prompt, seed=seed, steps=steps, cfg_scale=cfg_scale, sigma_max=sigma_max, sigma_min=sigma_min, batch_size=batch_size, sampler_type=sampler_type, seconds_start=seconds_start, seconds_total=seconds_total, negative_prompt=negative_prompt, init_noise_level=init_noise_level, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class e5_mistral_7b_instruct(FastClient):
    """
    Generated client for adirik/e5-mistral-7b-instruct
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f57685da-80aa-4e92-914a-c3e8faeae92d", api_key=api_key)
    
    def predictions(self, document: str, normalize: bool = False, task: Optional[str] = None, query: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            document: The document to be used.
            
            normalize: Whether to output the normalized embeddings or not. Defaults to False.
            
            task: The task description. Optional.
            
            query: The query to be used. Optional.
            
        """
        return self.submit_job("/predictions", document=document, normalize=normalize, task=task, query=query, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class whisper_subtitles(FastClient):
    """
    Generated client for m1guelpf/whisper-subtitles
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="21324c71-1e66-46e0-84bd-659122a52fd2", api_key=api_key)
    
    def predictions(self, audio_path: Union[MediaFile, str, bytes], format: str = 'vtt', model_name: str = 'base', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio_path: Audio file to transcribe
            
            format: Whether to generate subtitles on the SRT or VTT format. Defaults to 'vtt'.
            
            model_name: Name of the Whisper model to use. Defaults to 'base'.
            
        """
        return self.submit_job("/predictions", audio_path=audio_path, format=format, model_name=model_name, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class animate_diff(FastClient):
    """
    Generated client for zsxkib/animate-diff
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c5a85c36-0d23-47e1-b8d9-ab13ce68f709", api_key=api_key)
    
    def predictions(self, seed: int = -1, steps: int = 25, width: int = 512, frames: int = 16, height: int = 512, prompt: str = 'photo of vocano, rocks, storm weather, wind, lava waves, lightning, 8k uhd, dslr, soft lighting, high quality, film grain, Fujifilm XT3', base_model: str = 'realisticVisionV20_v20', output_format: str = 'mp4', guidance_scale: float = 7.5, negative_prompt: str = 'blur, haze, deformed iris, deformed pupils, semi-realistic, cgi, 3d, render, sketch, cartoon, drawing, anime, mutated hands and fingers, deformed, distorted, disfigured, poorly drawn, bad anatomy, wrong anatomy, extra limb, missing limb, floating limbs, disconnected limbs, mutation, mutated, ugly, disgusting, amputation', pan_up_motion_strength: float = 0.0, zoom_in_motion_strength: float = 0.0, pan_down_motion_strength: float = 0.0, pan_left_motion_strength: float = 0.0, zoom_out_motion_strength: float = 0.0, pan_right_motion_strength: float = 0.0, rolling_clockwise_motion_strength: float = 0.0, rolling_anticlockwise_motion_strength: float = 0.0, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Seed for different images and reproducibility. Use -1 to randomise seed Defaults to -1.
            
            steps: Number of inference steps Defaults to 25.
            
            width: Width in pixels Defaults to 512.
            
            frames: Length of the video in frames (playback is at 8 fps e.g. 16 frames @ 8 fps is 2 seconds) Defaults to 16.
            
            height: Height in pixels Defaults to 512.
            
            prompt: prompt Defaults to 'photo of vocano, rocks, storm weather, wind, lava waves, lightning, 8k uhd, dslr, soft lighting, high quality, film grain, Fujifilm XT3'.
            
            base_model: Select a base model (DreamBooth checkpoint) Defaults to 'realisticVisionV20_v20'.
            
            output_format: Output format of the video. Can be 'mp4' or 'gif' Defaults to 'mp4'.
            
            guidance_scale: Guidance Scale. How closely do we want to adhere to the prompt and its contents Defaults to 7.5.
            
            negative_prompt: negative_prompt Defaults to 'blur, haze, deformed iris, deformed pupils, semi-realistic, cgi, 3d, render, sketch, cartoon, drawing, anime, mutated hands and fingers, deformed, distorted, disfigured, poorly drawn, bad anatomy, wrong anatomy, extra limb, missing limb, floating limbs, disconnected limbs, mutation, mutated, ugly, disgusting, amputation'.
            
            pan_up_motion_strength: Strength of Pan Up Motion LoRA. 0 disables the LoRA Defaults to 0.0.
            
            zoom_in_motion_strength: Strength of Zoom In Motion LoRA. 0 disables the LoRA Defaults to 0.0.
            
            pan_down_motion_strength: Strength of Pan Down Motion LoRA. 0 disables the LoRA Defaults to 0.0.
            
            pan_left_motion_strength: Strength of Pan Left Motion LoRA. 0 disables the LoRA Defaults to 0.0.
            
            zoom_out_motion_strength: Strength of Zoom Out Motion LoRA. 0 disables the LoRA Defaults to 0.0.
            
            pan_right_motion_strength: Strength of Pan Right Motion LoRA. 0 disables the LoRA Defaults to 0.0.
            
            rolling_clockwise_motion_strength: Strength of Rolling Clockwise Motion LoRA. 0 disables the LoRA Defaults to 0.0.
            
            rolling_anticlockwise_motion_strength: Strength of Rolling Anticlockwise Motion LoRA. 0 disables the LoRA Defaults to 0.0.
            
        """
        return self.submit_job("/predictions", seed=seed, steps=steps, width=width, frames=frames, height=height, prompt=prompt, base_model=base_model, output_format=output_format, guidance_scale=guidance_scale, negative_prompt=negative_prompt, pan_up_motion_strength=pan_up_motion_strength, zoom_in_motion_strength=zoom_in_motion_strength, pan_down_motion_strength=pan_down_motion_strength, pan_left_motion_strength=pan_left_motion_strength, zoom_out_motion_strength=zoom_out_motion_strength, pan_right_motion_strength=pan_right_motion_strength, rolling_clockwise_motion_strength=rolling_clockwise_motion_strength, rolling_anticlockwise_motion_strength=rolling_anticlockwise_motion_strength, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class qwen1_5_7b(FastClient):
    """
    Generated client for lucataco/qwen1-5-7b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="5b024df1-64b6-4647-8a2a-7c64082f0339", api_key=api_key)
    
    def predictions(self, top_k: int = 1, top_p: float = 1.0, prompt: str = 'Give me a short introduction to large language model.', temperature: float = 1.0, system_prompt: str = 'You are a helpful assistant.', max_new_tokens: int = 512, repetition_penalty: float = 1.0, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            top_k: When decoding text, samples from the top k most likely tokens; lower to ignore less likely tokens. Defaults to 1.
            
            top_p: When decoding text, samples from the top p percentage of most likely tokens; lower to ignore less likely tokens. Defaults to 1.0.
            
            prompt: Input prompt Defaults to 'Give me a short introduction to large language model.'.
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic, 0.75 is a good starting value. Defaults to 1.0.
            
            system_prompt: System prompt Defaults to 'You are a helpful assistant.'.
            
            max_new_tokens: The maximum number of tokens to generate Defaults to 512.
            
            repetition_penalty: Penalty for repeated words in generated text; 1 is no penalty, values greater than 1 discourage repetition, less than 1 encourage it. Defaults to 1.0.
            
            seed: The seed for the random number generator Optional.
            
        """
        return self.submit_job("/predictions", top_k=top_k, top_p=top_p, prompt=prompt, temperature=temperature, system_prompt=system_prompt, max_new_tokens=max_new_tokens, repetition_penalty=repetition_penalty, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class llama_2_13b_embeddings(FastClient):
    """
    Generated client for andreasjansson/llama-2-13b-embeddings
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="760818eb-ff3f-4cfa-9c7c-1156dc83e0b1", api_key=api_key)
    
    def predictions(self, prompts: str, prompt_separator: str = '\n\n', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompts: List of prompts, separated by prompt_separator. Maximum 100 prompts per prediction.
            
            prompt_separator: Separator between prompts Defaults to '\n\n'.
            
        """
        return self.submit_job("/predictions", prompts=prompts, prompt_separator=prompt_separator, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class pyramid_flow(FastClient):
    """
    Generated client for zsxkib/pyramid-flow
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0ad6dc5a-4aeb-41e0-ad3b-083361dfe04b", api_key=api_key)
    
    def predictions(self, prompt: str, duration: int = 3, guidance_scale: float = 9.0, frames_per_second: int = 8, video_guidance_scale: float = 5.0, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Text prompt for video generation
            
            duration: Duration of the video in seconds (1-3 for canonical mode, 1-10 for non-canonical mode) Defaults to 3.
            
            guidance_scale: Guidance Scale for text-to-video generation Defaults to 9.0.
            
            frames_per_second: Frames per second (8 or 24, only applicable in canonical mode) Defaults to 8.
            
            video_guidance_scale: Video Guidance Scale Defaults to 5.0.
            
            image: Optional input image for image-to-video generation Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, duration=duration, guidance_scale=guidance_scale, frames_per_second=frames_per_second, video_guidance_scale=video_guidance_scale, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class nous_hermes_llama2_awq(FastClient):
    """
    Generated client for nateraw/nous-hermes-llama2-awq
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="fc4b0479-5850-4102-aa79-fc814970414a", api_key=api_key)
    
    def predictions(self, prompt: str, top_k: int = 50, top_p: float = 0.95, temperature: float = 0.8, max_new_tokens: int = 512, prompt_template: str = 'Below is an instruction that describes a task. Write a response that appropriately completes the request.\n\n### Instruction:\n{prompt}\n\n### Response:', presence_penalty: float = 0.0, frequency_penalty: float = 0.0, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            prompt: prompt
            
            top_k: The number of highest probability tokens to consider for generating the output. If > 0, only keep the top k tokens with highest probability (top-k filtering). Defaults to 50.
            
            top_p: A probability threshold for generating the output. If < 1.0, only keep the top tokens with cumulative probability >= top_p (nucleus filtering). Nucleus filtering is described in Holtzman et al. (http://arxiv.org/abs/1904.09751). Defaults to 0.95.
            
            temperature: The value used to modulate the next token probabilities. Defaults to 0.8.
            
            max_new_tokens: The maximum number of tokens the model should generate as output. Defaults to 512.
            
            prompt_template: The template used to format the prompt. The input prompt is inserted into the template using the `{prompt}` placeholder. Defaults to 'Below is an instruction that describes a task. Write a response that appropriately completes the request.\n\n### Instruction:\n{prompt}\n\n### Response:'.
            
            presence_penalty: Presence penalty Defaults to 0.0.
            
            frequency_penalty: Frequency penalty Defaults to 0.0.
            
        """
        return self.submit_job("/predictions", prompt=prompt, top_k=top_k, top_p=top_p, temperature=temperature, max_new_tokens=max_new_tokens, prompt_template=prompt_template, presence_penalty=presence_penalty, frequency_penalty=frequency_penalty, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class hunyuan3d_2mv(FastClient):
    """
    Generated client for tencent/hunyuan3d-2mv
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2dbbfde1-d700-46b5-b932-0e7f26ed309b", api_key=api_key)
    
    def predictions(self, front_image: Union[MediaFile, str, bytes], seed: int = 1234, steps: int = 30, file_type: str = 'glb', num_chunks: int = 200000, guidance_scale: float = 5.0, randomize_seed: bool = True, target_face_num: int = 10000, octree_resolution: int = 256, remove_background: bool = True, back_image: Optional[Union[MediaFile, str, bytes]] = None, left_image: Optional[Union[MediaFile, str, bytes]] = None, right_image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            front_image: Front view image
            
            seed: Random seed Defaults to 1234.
            
            steps: Number of inference steps Defaults to 30.
            
            file_type: Output file type Defaults to 'glb'.
            
            num_chunks: Number of chunks Defaults to 200000.
            
            guidance_scale: Guidance scale Defaults to 5.0.
            
            randomize_seed: Randomize seed Defaults to True.
            
            target_face_num: Target number of faces for mesh simplification Defaults to 10000.
            
            octree_resolution: Octree resolution Defaults to 256.
            
            remove_background: Remove image background Defaults to True.
            
            back_image: Back view image Optional.
            
            left_image: Left view image Optional.
            
            right_image: Right view image Optional.
            
        """
        return self.submit_job("/predictions", front_image=front_image, seed=seed, steps=steps, file_type=file_type, num_chunks=num_chunks, guidance_scale=guidance_scale, randomize_seed=randomize_seed, target_face_num=target_face_num, octree_resolution=octree_resolution, remove_background=remove_background, back_image=back_image, left_image=left_image, right_image=right_image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class imagebind(FastClient):
    """
    Generated client for daanelson/imagebind
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9e850624-b6b5-458e-a445-56ee6b06e29b", api_key=api_key)
    
    def predictions(self, modality: str = 'vision', input: Optional[Union[MediaFile, str, bytes]] = None, text_input: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            modality: modality of the input you'd like to embed Defaults to 'vision'.
            
            input: file that you want to embed. Needs to be text, vision, or audio. Optional.
            
            text_input: text that you want to embed. Provide a string here instead of a text file to input if you'd like. Optional.
            
        """
        return self.submit_job("/predictions", modality=modality, input=input, text_input=text_input, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class florence_2_large(FastClient):
    """
    Generated client for lucataco/florence-2-large
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="e45381de-1d62-4126-af47-130a1cbacc25", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], task_input: str = 'Caption', text_input: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Grayscale input image
            
            task_input: Input task Defaults to 'Caption'.
            
            text_input: Text Input(Optional) Optional.
            
        """
        return self.submit_job("/predictions", image=image, task_input=task_input, text_input=text_input, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class flan_t5_xl(FastClient):
    """
    Generated client for replicate/flan-t5-xl
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="505dcfd9-4852-4a03-a1d5-7dbbc4367f90", api_key=api_key)
    
    def predictions(self, prompt: str, debug: bool = False, top_p: float = 1.0, max_length: int = 50, temperature: float = 0.75, repetition_penalty: float = 1.0, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt to send to FLAN-T5.
            
            debug: provide debugging output in logs Defaults to False.
            
            top_p: When decoding text, samples from the top p percentage of most likely tokens; lower to ignore less likely tokens Defaults to 1.0.
            
            max_length: Maximum number of tokens to generate. A word is generally 2-3 tokens Defaults to 50.
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic, 0.75 is a good starting value. Defaults to 0.75.
            
            repetition_penalty: Penalty for repeated words in generated text; 1 is no penalty, values greater than 1 discourage repetition, less than 1 encourage it. Defaults to 1.0.
            
        """
        return self.submit_job("/predictions", prompt=prompt, debug=debug, top_p=top_p, max_length=max_length, temperature=temperature, repetition_penalty=repetition_penalty, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class robust_video_matting(FastClient):
    """
    Generated client for arielreplicate/robust-video-matting
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="708b7613-02bb-4077-becf-ff55eb4f2fb2", api_key=api_key)
    
    def predictions(self, input_video: Union[MediaFile, str, bytes], output_type: str = 'green-screen', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_video: Video to segment.
            
            output_type: output_type Defaults to 'green-screen'.
            
        """
        return self.submit_job("/predictions", input_video=input_video, output_type=output_type, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class styletts2(FastClient):
    """
    Generated client for adirik/styletts2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="a57378f6-be90-4d56-a9c0-746dcc612450", api_key=api_key)
    
    def predictions(self, text: str, beta: float = 0.7, seed: int = 0, alpha: float = 0.3, diffusion_steps: int = 10, embedding_scale: float = 1.0, weights: Optional[str] = None, reference: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Text to convert to speech
            
            beta: Only used for long text inputs or in case of reference speaker,             determines the prosody of the speaker. Use lower values to sample style based             on previous or reference speech instead of text. Defaults to 0.7.
            
            seed: Seed for reproducibility Defaults to 0.
            
            alpha: Only used for long text inputs or in case of reference speaker,             determines the timbre of the speaker. Use lower values to sample style based             on previous or reference speech instead of text. Defaults to 0.3.
            
            diffusion_steps: Number of diffusion steps Defaults to 10.
            
            embedding_scale: Embedding scale, use higher values for pronounced emotion Defaults to 1.0.
            
            weights: Replicate weights url for inference with model that is fine-tuned on new speakers.            If provided, a reference speech must also be provided.             If not provided, the default model will be used. Optional.
            
            reference: Reference speech to copy style from Optional.
            
        """
        return self.submit_job("/predictions", text=text, beta=beta, seed=seed, alpha=alpha, diffusion_steps=diffusion_steps, embedding_scale=embedding_scale, weights=weights, reference=reference, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class texture(FastClient):
    """
    Generated client for adirik/texture
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="95b3a073-a4da-4872-b8f9-104c433f72ae", api_key=api_key)
    
    def predictions(self, shape_path: Union[MediaFile, str, bytes], seed: int = 0, prompt: str = 'A next gen nascar', shape_scale: float = 0.6, guidance_scale: float = 10.0, texture_resolution: int = 1024, texture_interpolation_mode: str = 'bilinear', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            shape_path: 3D object (shape) file to generate the texture onto
            
            seed: Seed for the inference Defaults to 0.
            
            prompt: Prompt to generate the texture from Defaults to 'A next gen nascar'.
            
            shape_scale: Factor to scale image by Defaults to 0.6.
            
            guidance_scale: Factor to scale the guidance image by Defaults to 10.0.
            
            texture_resolution: Resolution of the texture to generate Defaults to 1024.
            
            texture_interpolation_mode: Texture mapping interpolation mode from texture image, options: 'nearest', 'bilinear', 'bicubic' Defaults to 'bilinear'.
            
        """
        return self.submit_job("/predictions", shape_path=shape_path, seed=seed, prompt=prompt, shape_scale=shape_scale, guidance_scale=guidance_scale, texture_resolution=texture_resolution, texture_interpolation_mode=texture_interpolation_mode, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class lgm_ply_to_glb(FastClient):
    """
    Generated client for camenduru/lgm-ply-to-glb
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="67404faa-b95f-4602-8033-815196098913", api_key=api_key)
    
    def predictions(self, ply_file_url: str, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            ply_file_url: URL of LGM .ply file
            
        """
        return self.submit_job("/predictions", ply_file_url=ply_file_url, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class llava_13b(FastClient):
    """
    Generated client for yorickvp/llava-13b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="936c7574-c12b-4955-9db8-e3f1ede0c7f3", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], prompt: str, top_p: float = 1.0, max_tokens: int = 1024, temperature: float = 0.2, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            prompt: Prompt to use for text generation
            
            top_p: When decoding text, samples from the top p percentage of most likely tokens; lower to ignore less likely tokens Defaults to 1.0.
            
            max_tokens: Maximum number of tokens to generate. A word is generally 2-3 tokens Defaults to 1024.
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic Defaults to 0.2.
            
        """
        return self.submit_job("/predictions", image=image, prompt=prompt, top_p=top_p, max_tokens=max_tokens, temperature=temperature, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class mamba_2_8b_slimpj(FastClient):
    """
    Generated client for adirik/mamba-2-8b-slimpj
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="682c9464-b04c-4f3a-b6da-4da525b2a84d", api_key=api_key)
    
    def predictions(self, prompt: str, top_k: int = 1, top_p: float = 1.0, max_length: int = 100, temperature: float = 1.0, repetition_penalty: float = 1.2, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            prompt: Text prompt to send to the model.
            
            top_k: When decoding text, samples from the top k most likely tokens; lower to ignore less likely tokens. Defaults to 1.
            
            top_p: When decoding text, samples from the top p percentage of most likely tokens; lower to ignore less likely tokens. Defaults to 1.0.
            
            max_length: Maximum number of tokens to generate. A word is generally 2-3 tokens. Defaults to 100.
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic, 0.75 is a good starting value. Defaults to 1.0.
            
            repetition_penalty: Penalty for repeated words in generated text; 1 is no penalty, values greater than 1 discourage repetition, less than 1 encourage it. Defaults to 1.2.
            
            seed: The seed for the random number generator Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, top_k=top_k, top_p=top_p, max_length=max_length, temperature=temperature, repetition_penalty=repetition_penalty, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class real_esrgan_video(FastClient):
    """
    Generated client for lucataco/real-esrgan-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f7b0ed6f-3794-4b3f-a273-f2d96d2b699a", api_key=api_key)
    
    def predictions(self, video_path: Union[MediaFile, str, bytes], model: str = 'RealESRGAN_x4plus', resolution: str = 'FHD', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video_path: Input Video
            
            model: Upscaling model Defaults to 'RealESRGAN_x4plus'.
            
            resolution: Output resolution Defaults to 'FHD'.
            
        """
        return self.submit_job("/predictions", video_path=video_path, model=model, resolution=resolution, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.tencent.hunyuan3d_2mv import hunyuan3d_2mv
from socaity.sdk.replicate.tencent.hunyuan_video import hunyuan_video
from socaity.sdk.replicate.tencentarc.animesr import animesr
from socaity.sdk.replicate.tencentarc.gfpgan import gfpgan


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class incredibly_fast_whisper(FastClient):
    """
    Generated client for vaibhavs10/incredibly-fast-whisper
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="93029465-6cee-4127-ad03-389a16dd9f6f", api_key=api_key)
    
    def predictions(self, audio: Union[MediaFile, str, bytes], task: str = 'transcribe', language: str = 'None', timestamp: str = 'chunk', batch_size: int = 24, diarise_audio: bool = False, hf_token: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio: Audio file
            
            task: Task to perform: transcribe or translate to another language. Defaults to 'transcribe'.
            
            language: Language spoken in the audio, specify 'None' to perform language detection. Defaults to 'None'.
            
            timestamp: Whisper supports both chunked as well as word level timestamps. Defaults to 'chunk'.
            
            batch_size: Number of parallel batches you want to compute. Reduce if you face OOMs. Defaults to 24.
            
            diarise_audio: Use Pyannote.audio to diarise the audio clips. You will need to provide hf_token below too. Defaults to False.
            
            hf_token: Provide a hf.co/settings/token for Pyannote.audio to diarise the audio clips. You need to agree to the terms in 'https://huggingface.co/pyannote/speaker-diarization-3.1' and 'https://huggingface.co/pyannote/segmentation-3.0' first. Optional.
            
        """
        return self.submit_job("/predictions", audio=audio, task=task, language=language, timestamp=timestamp, batch_size=batch_size, diarise_audio=diarise_audio, hf_token=hf_token, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class magnet(FastClient):
    """
    Generated client for lucataco/magnet
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="e0de7ff2-1a9b-40ba-9c94-4c0f654d168d", api_key=api_key)
    
    def predictions(self, model: str = 'facebook/magnet-small-10secs', top_p: float = 0.9, prompt: str = '80s electronic track with melodic synthesizers, catchy beat and groovy bass', max_cfg: float = 10.0, min_cfg: float = 1.0, span_score: str = 'prod-stride1', variations: int = 3, temperature: float = 3.0, decoding_steps_stage_1: int = 20, decoding_steps_stage_2: int = 10, decoding_steps_stage_3: int = 10, decoding_steps_stage_4: int = 10, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            model: Model to use Defaults to 'facebook/magnet-small-10secs'.
            
            top_p: Top p for sampling Defaults to 0.9.
            
            prompt: Input Text Defaults to '80s electronic track with melodic synthesizers, catchy beat and groovy bass'.
            
            max_cfg: Max CFG coefficient Defaults to 10.0.
            
            min_cfg: Min CFG coefficient Defaults to 1.0.
            
            span_score: span_score Defaults to 'prod-stride1'.
            
            variations: Number of variations to generate Defaults to 3.
            
            temperature: Temperature for sampling Defaults to 3.0.
            
            decoding_steps_stage_1: Number of decoding steps for stage 1 Defaults to 20.
            
            decoding_steps_stage_2: Number of decoding steps for stage 2 Defaults to 10.
            
            decoding_steps_stage_3: Number of decoding steps for stage 3 Defaults to 10.
            
            decoding_steps_stage_4: Number of decoding steps for stage 4 Defaults to 10.
            
        """
        return self.submit_job("/predictions", model=model, top_p=top_p, prompt=prompt, max_cfg=max_cfg, min_cfg=min_cfg, span_score=span_score, variations=variations, temperature=temperature, decoding_steps_stage_1=decoding_steps_stage_1, decoding_steps_stage_2=decoding_steps_stage_2, decoding_steps_stage_3=decoding_steps_stage_3, decoding_steps_stage_4=decoding_steps_stage_4, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import List, Union, Any

from media_toolkit import MediaFile


class video_merge(FastClient):
    """
    Generated client for lucataco/video-merge
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0a9bb226-1d9f-4252-bff3-7a5de0c58d55", api_key=api_key)
    
    def predictions(self, video_files: Union[List[Any], MediaFile, str, bytes], fps: int = 0, width: int = 0, height: int = 0, keep_audio: bool = True, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video_files: List of video files to concatenate
            
            fps: Output video frame rate. If not specified, uses first video's fps Defaults to 0.
            
            width: Output video width. If not specified, uses first video's width Defaults to 0.
            
            height: Output video height. If not specified, uses first video's height Defaults to 0.
            
            keep_audio: Whether to keep audio in the output video Defaults to True.
            
        """
        return self.submit_job("/predictions", video_files=video_files, fps=fps, width=width, height=height, keep_audio=keep_audio, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class stable_diffusion_x4_upscaler(FastClient):
    """
    Generated client for lucataco/stable-diffusion-x4-upscaler
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2a64befb-cd6c-46d1-a751-91599ac9ea11", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], scale: int = 4, prompt: str = 'A white cat', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Grayscale input image
            
            scale: Factor to scale image by Defaults to 4.
            
            prompt: Input prompt Defaults to 'A white cat'.
            
        """
        return self.submit_job("/predictions", image=image, scale=scale, prompt=prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class ace_step(FastClient):
    """
    Generated client for lucataco/ace-step
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="1b23e5cb-194e-40d6-9adc-b422788de890", api_key=api_key)
    
    def predictions(self, tags: str, seed: int = -1, duration: float = 60.0, scheduler: str = 'euler', guidance_type: str = 'apg', guidance_scale: float = 15.0, number_of_steps: int = 60, granularity_scale: float = 10.0, guidance_interval: float = 0.5, min_guidance_scale: float = 3.0, tag_guidance_scale: float = 0.0, lyric_guidance_scale: float = 0.0, guidance_interval_decay: float = 0.0, lyrics: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            tags: Text prompts to guide music generation, e.g., 'epic,cinematic'
            
            seed: Random seed. Set to -1 to randomize. Defaults to -1.
            
            duration: Duration of the generated audio in seconds. -1 means a random duration between 30 and 240 seconds. Defaults to 60.0.
            
            scheduler: Scheduler type. Defaults to 'euler'.
            
            guidance_type: Guidance type for CFG. Defaults to 'apg'.
            
            guidance_scale: Overall guidance scale. Defaults to 15.0.
            
            number_of_steps: Number of inference steps. Defaults to 60.
            
            granularity_scale: Omega scale for APG guidance, or similar for other CFG types. Defaults to 10.0.
            
            guidance_interval: Guidance interval. Defaults to 0.5.
            
            min_guidance_scale: Minimum guidance scale. Defaults to 3.0.
            
            tag_guidance_scale: Guidance scale for tags (text prompt). Defaults to 0.0.
            
            lyric_guidance_scale: Guidance scale for lyrics. Defaults to 0.0.
            
            guidance_interval_decay: Guidance interval decay. Defaults to 0.0.
            
            lyrics: Lyrics for the music. Use [verse], [chorus], and [bridge] to separate different parts of the lyrics. Use [instrumental] or [inst] to generate instrumental music Optional.
            
        """
        return self.submit_job("/predictions", tags=tags, seed=seed, duration=duration, scheduler=scheduler, guidance_type=guidance_type, guidance_scale=guidance_scale, number_of_steps=number_of_steps, granularity_scale=granularity_scale, guidance_interval=guidance_interval, min_guidance_scale=min_guidance_scale, tag_guidance_scale=tag_guidance_scale, lyric_guidance_scale=lyric_guidance_scale, guidance_interval_decay=guidance_interval_decay, lyrics=lyrics, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.arielreplicate.deoldify_video import deoldify_video
from socaity.sdk.replicate.arielreplicate.robust_video_matting import robust_video_matting
from socaity.sdk.replicate.arielreplicate.stable_diffusion_infinite_zoom import stable_diffusion_infinite_zoom